
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xde*\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x9e*\x00\x00\x00\x00\x00\x001N\x8b\xcd\x13\x8a\xd5/\x05\xd2\x17&)e\x98\xd5\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC'
        b'\x15Z,F\xdc\xcc~\xc2=\xe7zWe\xb9V\r\xf0\xe7\x81\x95t9G1\x87\xd9|\xee\xf6>\xf1\xfe\x1c\x0e\xdb\xda8i\tZ\xeenk\x90\r\xe2\xae\xa4Q\xb6\x98\xca\xe5\xafbr\xa6\xa4\xb3\x16z\xbf\tW'
        b'\xf3\xbe}\x1e\xb7\xea\xc8+\xfd\xa0\xd0\x84/w\xae\xae\x8b\x15\xf1\xe1\x0f\xbf\xdf\x94\x01\xd8o\x02\xe8-\x19V)\xee\x14>\x03\x12\xfd,\x95\xe2W\xbc\x1d\xe8\xf8\xc0ft\x8b\xe1&R*\xb8\tB\x04\xfe\xb7\xc4Xt'
        b'\xe6\xa1\x0b`\x04Q\xae\xa2\x9a\xc6#\xe6\xdc\xb1aq\x10\xec%\xebo(\xaaG\xd1\x8fo\xde\x02\xcc\xe5\xa67?\xc2\xf7\xc9d\x01\xc1\x18[Rai\x89\xf9\x0fM\x7f\x85\x03\t?\xa0\xba$a\xdb\xaa\xee\xe3\xe2\xdb'
        b'\xe6\xeb\xaf\xd42&O\x90\x1b\xbd"\x93:\xbd\xf4\x04\xf0H\xc8\xb55H8f+G\x83\xe4\xd1\xc28\xd5\x11\xf3(\xe3A\xec.f\xca\xc4\xa0Q\xc4\xd5\xe4=\xd6Om&\xadsq"\x8dc\xb2v\x1fzpY'
        b'/\x15\x7f]`7\xb6\x8f\x1fis\xe1NO\x13\x13e\xee\xf3\x8b\xb8\xc0\xb8\xb2\xe7X\xd9+\xb1\x8d\xca\xfd\xd0^5\x83=\xb0yn\\\xb9\xdb\xe9\x9e[\xbf\x05\xdf\xe8\x1cj\xd6\x16\x7fM\xf6\x82m\xa2Z\xf0Gt'
        b'>\xab\xae"*n\x88\xd6\x86y\x87\xf2\x92\xb1\xa3\xd6\x1a\xc3\xf5\x9b\xe4\xad"\xe0\n\xbc\xbe\xbaZ\x1b\xd2`\xba\xf4\xbcyB\x82a\xa6\xc6\xd5\x00\xbd\xae\x1e\xc7\xba{\xf66`d\x89A\xde\x15\x10"A\xd6"\xa9\xcf'
        b'\xd3\xc9\x14\x8f4\x8d\xd4\xb6\x85\xc3\xaex\x191\xf9$um\xdd\xfb"\x0f\xc6O\x96s\xfb\x1ac\x88\x06\x02\xec\x95\xde\xdd5\x9f/W\xc5O\x91j\x7f\xf4\x9aw=)\x19$m\x19\x94\xe8{\xa6\xf0\x11\xff\xadk\xa9'
        b'K\xff\xc3ay\xf2\xba9\xacL\xf4?u\xd62\xee\xc3\xac\x84kl\x93 dY\x9cy\xfa\xf3\x8a{\xd3\xfc\x0f\x06\xcb{\x82\x16\xae\xf82\xfbD5\x01\xef\xe1\x10z\xd8y\xf0\x13\xaa\x91\xee\x8fR\xfc\xfa\xea)G'
        b'}VqH\xaf%\x93\x87\x8e\xc5pP\x1b\xdbj\xd30\xfe~\xf1v\x07\xcayf\xef\x06\xd4\xb1U\xac`^\x88\xf3P\x1d*\xcb\xdaO\x03\xabX\x13j\x11\xc7\x91\xd5\x81\xb9\x00q\xde\xc5\xfa3\xe2\xbf\xf0CF\xf2'
        b'\xf1\xa6\x19\xaci\x80b6J\x0b\xd4\xc3\xf8\xf3e\x193L3\xeb\xf8\xec\xba\xc4\xbc\xa6[\r#\x1c\xed\xb4q\x84\x83\xdeUR\xaa\xbe\x9eUJYpR\xb3\xfd\x03c**"\x05\xd4\xfe\x17\xf9e\xde\x11q\xa3~'
        b'\xa7\x03\xbf\xb9\x98\x99\x16cT\xbd\xaf\xe2\x1a\x9be\xe3P\xdf\xa5\xfd\xa0\xc7u\xd6\xe4\xcc,\x8a\x8c\x90\xdas\xd7\xa2"Gr\xdf\xd9\x97\xac\x13C\x14\x9f4\xff\x11}\x81\xbc\x8d\xa6\x8d\xdd\x12\xb6\xcc\xbbC\xe9O\x9d\xe3'
        b'=\xa5\xf9\xad)\xcd?\xb0\xc3\xf44\xdf\xfd\x85\xba\xd4\xc0\xd8\xb5s\xf6\r\x1e\xbdp\xda\xf6\xd5\xdbLJC\x92b\xbaT\xf41\xa6\xa8\xdff\x87Q\xf6\xaf<Kj\xe1\x1c\xe8#\x16C\x02d\x10\xd7\x14z\xaf\xf0\x0c'
        b'\xe8\xfcWa\x9d{\x96\x10\xce\xa0:y\xf9\xfb\xecw\xf6t{\xedA4\x06\xd3\x8c-\x93-\xeavr\x1a\x88\x14\xc2\xec\x96\xcd@\xaa#\xd8\xa5\x9cQ\xdbs\xe6Qz\xdfO\x03\x04\xbb\x87(\x18\x82}\xec\x04\xeb\x19'
        b'A\x8dZ\xd4\x80N4A\xc1\xde\x145,M\x9b\xed\xa8k\xed\xdf\xffa)\xa8\xf2Q\x9c\xc1\xa6b\x9f\x19\xe1\xdc\x9a\xdd\x9a\xb4\xfbu\x95\xb9d\xb1!/TYro\x10\xf7\x0e\x91\xd9\x84P\x14\x16L\xb8H\xad<'
        b'\xfa\xf6\x963+\x1bd\x8aJ\xd9|\xc0;\x03[C-u{~\xbdsG\xc2\xb2\xdb\x85(\xb8^,+\xcc\x7f\x94,/C;\xfc[\x90\xf2\xe3c}\xba\x80\x9e\xc2E\x19S\x90#i\x1bg\xdf\x00\xfb\xea\xa8\xc9'
        b'\xae\xfe\xf3\xd6\xff\xa3\xd1d\xb0@\xa7n\xf0p)\\\x8f\xf81\xfe\xbc\xb2\xcc\x18\x967\xd6\xe2y\x80\xe3\x80\xda\xd5\xe4\xea\xc9\xc4\xd55<\x02\xd1H\xbb%<\xd73\x02`=\x93&\x0b\x99+!\x02A%\t>\xcd'
        b'\x90\x98\xbe\xed\x916rO\xbb\x06y\xf4q\xae,\x03`Z*`4\xe2\x959!\x07\xec\xd7\xcd\xfd\x05\x01\x99!h\xe5\x8aF\x11\xa4\xbc3_\xb8\x0e\xc7\x92\xd9\x8f\nt\x1f{\xea\x92m\xae\xdcq\x9f\xe0\x16\xf3h'
        b'\xf0\x1bt\xc2\x1b:n\xd5\x95\x85$\xe3\xa7q\x10\xa5\rD\xbc~t\x8e\x1bE\xdbeG\x8ed\xf8\xff\xc4\x8a\n\xd0\xfa\xf2\xd2\xda<\xa9K\xc0^\r\xc2P\xc5\xde\x11\x9b\x02\xddd\xd5\x8c\xd4\xee\xb9\xcae6p\x7f'
        b"2 \xdcC\xd3t/\xe6\x01\r\xa0U\xcf\xf4\xa1\x9e\xfc\xcb\x8dN\x80\x841\xfd\xf9\xaa\x16\xe2\xab\xf1\xc6\xa8e\xfeo4\x1b\x82\xdbXq\xc6\xcd\xd4`';\x88\xa1\xb2+Q\x93#\x03\x19\xd1B\xef\xb3k\xee\xa1O"
        b'\xee\xbc$\x88\x9e\xeetC\xc0*\x98Lh\x81@7\xbb\xed2\x81)\x9a=\x8e\xb1\x95\xd7\x1a;w\xa0\xa9A\xfbOr\x91+\x04|D\x0b\xae\xcd\xa5\xbb_\r\xb2m\xc4\xe1\xbc\x9ds\xf5qL\xa2\xe6\x03\xd1\xd6\x83'
        b'\x83\x93n\x95\xcb\xc3\x8f\xad\x92\xb9\xa3 )\xe6%\x17\x1b\t`\x8c\x97\x90\xdc\x9c\x03aM\xe5\xb0\xc6\xe1&\xf5\x82\xdas$K\x15\x03-\x06\x8f\x8e\x93\x13\x01\xc5[\xf7D\xa0\xf1\xa7!\x00\x86\x9d]\xe6\xf9\r\xc9|'
        b'\x17|\x043\x98!l\x9c\x91\xcc\xcf~0\x84\xf5\xe4i\xd4\xe4\xf0\xd3\xb7\xa8\x83\x8f\x8d\x9e\xb1\xd9\x80C\x92\xf2\x9e\xc4h\x8f\x9dB\x8a\xb9A7\r\x8d"\xd7\xa3\x0c\xc5\x08\x1a\xeb\x9e\xf8+.\r\xd3\x0b\xf7"\x13&'
        b"\xc0\xfe\xba\xfc\xc8\xc0\xfdx O\xe5\n^\xf8\xf3L\x14\xbc\xd3\xbd[\xa6y\x93\\oL\xcd.\xa4\xb7\x80\x95\x87\xdbf\xd6\xb0R\xa3y\xd6\xb9Z\xd8+\x07\xb4\xe6\xef8\xa7;\xa9\x07\xf9\x896'ud\x08\x9a\xc5"
        b'\x8cV\xaf\xd7\t\xb6n\x0f\xea\x00w\xb4u$6\x10\x1c\x9e/\x05\x04\xd2c\xf2N\n*\xb6\xb5\xd6\xf7\xcbT\xbc\xee\xbd\x1eaJ\x8a]\xd5\xde\xb9\x06\xf9\x9d\xb9\xf4\xaf\x17 9\x13\xb1\x8b\xe0\x04Z\x99\xa0\xa6\xe1\xdc'
        b',\xdb\xdb\xd7n\xb3\x07,\xa4\xbd/\xed\xcb\xc5\xe0\xcc\xdcz\xa2\xff%\x93\x93w\xe2\x0fv\xb2\xe8\x820x\x1d\xa2<\xb5\xc8\xe0\xd2\xb1\xecj\xe3\xd8\xcd\xfd\xe0\xea\xbc\xe24\x08#\x9a\x071\x1f\xa6lBz\xa2\x84\x1d'
        b'KI!"\xae\xc8\x8e\x02\xf3\x95H\xcb>\x0c\x9f\xe3x\xda\xff\xfb[\xcfd\xb9D\xcc\x91\xc7\xab9\xdd\xa0\xb9\xab=\xd30\xca\xed\xe5\xc7\x9a5=\xe0K\xa9\x9d\'\xf2\xa2\xa3\xf3\x00\xcfN\xd6H\xb7~\xff1\x83W'
        b'K\xb6\xdb\xc2(\x1dP#\xd3\xa0\xda9\xbc{\xa7\t^e )\x9f\xa8\x1f|6Gc\xe5H|\xf3\x8c\x13\x81\xbc\xe1\xbak\xfbP\xc6\x93teB\xb9\xb9\xfd\x00g\x17\xd3\x9e\x8a\xd4\xc1\xc5n\x1a2\t\xfa\xcf\xca'
        b'[\x93O\xac6j\xa4\x9e\xcd\x1d\x81\xcf%y\x99l\x88/\x17{\xf8\x87\xf3\x8e\x1c\xd4\xc5\x08\xae\x1eOy\x92\xc82\x12\xdc\x7f\xa2j1\x84\xb6\x88[\xcd\xae\xa12C\xeeE\xce\t!\xd0\x92\xa7\x12!\x81\xb6\x0bn'
        b'to\xba\xf3\xa3\xc4\xf5\xe1\x84\x82\xe6\x95\xd9\x9dR\xaf>h\x95\x00$\x87C\xe9y\xf0=\xbb\x00\xe9o\xbf}\xf0\x8b\x15\xda\xac\x9a\x8fvQ?\x19\xda[\x9a\xe1`\x98\xde\xeec~N\xbe\xe7\xde+\xac~Mj\r'
        b'\xc8y:<\xbb\xabj\x9f<\xcf\x15\xb0[&X!\xc0A3\xbfd\xfd@\xbcV8c\xa5\xb1\xf8x\xa7\x88AL;3\x1e\xbd\xa4\x92?\x8d\x94\x0f\xe5\xf5R-\x98\xa1\xbaS&\xc8\xae*9[\x84\x124%K'
        b'\xd4}\xe2\xbc3h\xa1xV\xb5\x07\x12g"\x1db\x81:\x0b!\xe6!\xc5\x86\x80\xafR\xd21\xc0\xbd\xcf\xa1\xf1D\x15\xac\xbf\x10Y\xcb\xa7-;,\xa7\x9a*\xcbI__\r\x1c\x05\xed\xcaUY\nC\x98\x0b\xda'
        b"`\xd0\xb4*\x8aW\x9d\xce\x86e\xc3,\xba\x17\xac\xb2ZA\x8b\xeb\xde_os\xfc;i\x8blI\xc0\x03u\xeb\x9f\x02\xf3\x1fMl\xedz/e\xc8%S\x07\x17A\xe2\x12zq\x93\x88'D\x81\xa1e\xf9W+"
        b"'\xf5\xc0\x976\xa50AzqW\xbb\xb5\xcf\xd1q&\xa9\xb1\xea\x9a\x85Z\x0e&\xe9\xdc\x19\xbbsf\xec\x86jjl\x92b\xc18\x9fU\xd6\x85\x87{\n\xa9\xa4R\x0b\xa9\xed5\x00\x02p\xd4\xca/\xbe\xff\x8e5"
        b'\x02\x83\x81\x057\xd2`\x02\x9f\xc8\xf4!\xc5\xda\x10\x0f\xa6\xc7\xde$\x94\xc0f\x94\xe6X|\xd96v\x88\xa6\xf2\xd0f\xa3\xc7s\x0e3\xa1\xa2\xc51\xc0>*z\t\xe3\x8b\x85;\x1c\xa0^e\x9d\xaa\x8f\xc4\xb07\xc4'
        b'i\xdc/\xb5-\xfb\xd51\xdc\t\x83\x1f\xcf`8]\xcf!\xc3\x94a\xb7r\x99\x97\xce{H\x0e\xf8\x99\n\x92\xd8\xe9\x1b9\x12e\x02\xdc\xe0\xa3\xf3\xe4\xf0\xf4\xcb\xa1\xb6\xf2\x06\xa8\xf8\xdb%\xa9\x11\xf7}\xfb7>G'
        b'\xc5\xa1\x8cF\xcfc\xeacL=\xce\xbb\xc6\x1c\xbey}\x9a\xcc:8K\xfa\xb3\xd8\x19\x92x\xf5M+\x13\xa8\xeb\xcc\xe4]54\xd1\xe0\x8db\xb3\xbf\x87y\t\xa8@G\x07\xef\xf3\x9a\xa8\xcbFM\xe3\xcdJ$\x8e'
        b'\x81f\xbe1\x17Et!!,I\x9f?WH\x97\x17\xaf\xb7+\xe2\x17\x9b\x7f\x07Nw\x1e\x00\xef6;$Q\xc3\x9c\xf7j\xf68\xe0\x11\n\x0b\xed\x1c\xeb\r\xfd\xa0\x88\xe0\xa9m\x85w\xf1[\xa5\xacD\xca<\x0b'
        b"\x8f\xc0v\x1bG\xcd\xf1\xe1\xea2\x8d\x06sk\xe3\xd8e,\xd7\xa9jq\r\xf75c\xb7\xb0qX\xe6k'\x88B\xbc\xdc\xb5<\xfbk=\x8a\x8d\xa2%%dx\xf4M\xde\x98?9\xee\xe4\x95~\xb4\xc0\xfa~b"
        b'\xbd\x87\x88\x890+\xe6\xec\x9f\xfak\xcb\x9e\xc6\xa5\xf0\xa5\x99Vr\xf2\xb2;\xde\xee\xb2\x84\xd1\xde\x08*9-\t\x00\xc8\xe9\x97\xea\xe5\x8e\xb9\xfe.\xf4#\xdd\xcc\xf0\x15\xd2T\x8b\xd7fv\xfbl"\xf7<\xf9\xb2Q'
        b'\xfaU*\x9b\x15z\xd4O_O\x13|\x0e\xf0\x8a\xfd\x06gR\x89\xe0\xf6\x8d\xb6\xa0$Ki\xe3\x9f\x95y\xcb\xf9\xa4\xdb\xae\xa1\xb5\xd4HH\xa0\xc3\x94u\x8bLk\x1f\xd3(\t\xb5.\xfd}\x91\x93Oa@ql'
        b'\xb90Wl\x19\xd2\x1f{Ky\xd3\xab\x88\x07`]\x11\x16\xc4\x91V\xb2f\xc4\x9e\x19\x9e\x89p4\x17\xfc\x9c\x9d\x9d\x13\xd8r\xe8\x85\x94\xcc\xf6w\xe4]\xea[\xf4\xed\xe7\x9aQ\xf9\xfc\xa5Z\x92\xdf9\x1eQ\xd8='
        b"\x14\xdb/\x86r\xd6\x0ew\x1b\x82\x193\xc5z^b\xb6\xf2\xe1\x86\xcb\xb6\xe0\x1e\xce\xfb\x8b\x05\xf1\xe6\xd3/l\x91s\xf5\xea^\x00\x85\xf9\x17\xdf\xb25^\x84\x13';\x8d\xd6\xd0:}\x9e\xf0\xb8~\xc9_\x17\xfe\xcf"
        b'5\xfeG<\xb7S\x99\t\x0f\xa1\x96\xee*\xd8x5\xa95W\xe8"&\xdf\xbf\x95\xd4\xd3\xcb\xb5\x81\x86\x9cl__w\xa7`\x0b\x86\xd9\x07Q\xb4\x93\xaf\x90\x81\x06\xb9p\n\xaeb\xdeZ\xf6P\x8e\x05\xf3\xaa\x9e\x88'
        b'\xfb\xca\x99+,\xfe\xb6&\x90<"*uhH\x9c\xd48\x8bB\x18\xb2\x8d\xd2m:u\xb7\xc1d\xe6\xaa\\u\x1a\xb1k\x87\xf8\xdb/\x17n\xe9\x8d%m9\x0bV\xe6G\x85v\x0e\xdd\xdc\xdc\xf4\xeb\'r>\xe4'
        b'\xcb\xa5\x9c\xe4xhj\xaf\x9a\xb3\xa5C\xb9&\x8e\xbe2\xc8\xc4\x10m\'\xf1\x01XT\xcc\x0f\xe6\x94\xe4\xaaG\x964\xfe\x9e\x92*\xcb\x8f.g\x8a/\xb5\xeaK"\xad\x82bNPr8/y\xec\xe4\x01$\xb7z'
        b'`\x8ap\xe2v\xb7\x10\xeb\xd1\x93d\x04\xbdn8w\xd7\x8a\x18\xa0\x93"p\xbe\xe7\x0c\xf2\x1f\xf1\xe2ke?\xf0\xf9\x1f\xc7\xea7\x01E\xd5\x1e+\xe2D\x97?\x89\xc1\xd1^\x1c\r2@\x1d}\x98o\x10\x1c\xca\x02'
        b'f?hh.,-J\xd6\x9e\xfa\xca\xedG\x9aH\x85\xd4"Ve\xea\xb6G\xc0\x87\x10\xa1\xdd\xe5~<\x05\xfa\xe0K8\xc3\xf4\xd1\x835\xfb\xbb\x86\xa9?V\xd0\xd2\x16E\x0c\xb7\xf8_\xfe\x03yJSZm\xd2'
        b"\xad\x96\xa2\xc2\x1a\xbf\xbbr\x02t`\xc8\xf8\xf2\xc6i\x92'K;Z\x11=\xfct\x7f\x80m\x08\x96\x90D>Y\x9d>\xb0I3\x9d\xb4\xe0\x07c\x15\xd9\xb5q#\xa5\xca\xd0\x0fW\xaag\xba\xd6\xe6\x8e\xd8b\xae8"
        b'\xb9\x9e\x0b\xae\xef\x84\x7f\xd7\xd35p-A!$^\xc1\xb3\x04\xcd\xc0A\x81z\x15J\xa0\x84p\xfa\xc4\x1a\xeb_\xfd\xb65(2\x8e\xff\x07\xe5\xc9\xdb\xbd\xfd\xc8@\xc3\xf1\x13\x88\x8c\xa8}\x8d\x7f\xee\xa6\xcb\xa2z\x11'
        b"\x10\xa8\x8f\xf0\x88\x10\xcf\x85\xe5\x0f\xad\x9c\xd1r{\xd5c\xdd\x0fx\xb2\xa0\xf32\xa8\xbe|{\x82r\x1a\xd2r1H\xc2M\x07\xe19\xa5R3\x8czE-\xdcI\xbe\x01\x17[\xf0'\xe8\x1f\x91\xeev\xf6^\xca\xd4"
        b'\xe4=\x12\xac\x15\x1a\x1d\xdfK\x03-\xebc\x15L\x15\x92=1\x00a9m2-\xe9#\xdc`\x18\xe4\x01j\x1c\x81\xef\xf1%\xcem\x13\xfc5\xb4\xc7\xc8q\xda\x8c\xc1\x83\x1cE\x19\xcdw\xe9\xf0\x10\x88z\xe3\xb3\xed'
        b'<]\r\xa5\x16\xc2EC\xde\xda\x9e1\x19}\xcb\x9aiLL\xc2\xe3K\xccC\xd8\xcf\xd18\x01\x13\x04X\xfcIH\xf2\x1d\x82\xc4\x97\xad\xa6\x89\x9f!0\xaaX\xff\xf7\x9e\xc4\xa8\xe3VaL\xce\x88O\x1f%\xf8*'
        b'\xd0\x93{R\xbe\x13\xa1"@eL\xe4\xfe\xf8\x97Ph\x9a93"\xaf/\xd4\xae\xda\xb0\x8b\xfd\xe5 \x1b\xa3x\xe8")\xe1\xf3\x11*\xb5\xcd\x9a\x88\xa3\x14\x07\xe3\xce\xaak\xdc\x80{\xb7\xcc\xc4\r\x88\x9a\xa9\x9ct'
        b"\xa6\xce8\xb2\xfe\xbb\xde\xf7\xd9\xbav\x97A\x04\x07\xd4]\xe0\xe1I\xf9\xe3j\xc5+\xda2\xe7\x8c\x94^H\x84\xd3\xd3\xde;vR\x15\x17'\r\xc4\x03\xe5)\x80$\x8c\xa7LQ:}\x97\xc8?\\|'\xfa\xd8\xac"
        b'\x19\x0f$R\x0b\xb3\xe1\xf4H\xa1\x0bD\xdd\xbby\xe7H\x86\x03W\xec\xacU4\x00Q%RN\xc3R\xda\xf0\xa0\'\xd2g\xe7\x17\x0f\xa2zp)\x8a\x06\xe4\x8aM\x9e"~\xf1L+\x9d\xf4c\x9f\xe6\xc9\xc9o\t'
        b'\xf7\xe9a\xd54w-\xf9x\xd3j\xab|a\xaf\x14-\rV\x95Y5\x9f\xa3\xa3@\x80\x86\r\x01*#\xedQ\xed\xc7\\\x1bztu\x8a\xfb\xbf<\xc1\xec\x87v\xb3z\xbcV4*RM\x0c\xb0P\xac\xcaPm'
        b'cT\x1d\x04\\\x1b[k>\x82\xbf\xd8EA\xd7\xee\x08`\x88\x03>&\x0c\x05\xea\xe4\xbd\xc2I\xd7\xf1%\xd1\xf1\xa6\xb7>\xd0E\xe2ZY\xe5\x05a=\xaeH\xf9i\xf2x\x00\xf3\x1e\xb3!\xf59\x8c\xa3\x02\x8a\xb9'
        b'\xa2\xa3\xd3\xc2\xff`\x8eo\xc2=\x89>\xccZ"\xd2\x00\xedD/(&?\xe0<\xae\xe2Q\xae?R\x8e\x8bYFO;do\xd4QM\xc80H\xc8\xc9\x81\xaf\x9b\x08\x89y[\x89\xd9\xf1\xbe*)\x03^A\xf3'
        b'\xb6uO\xd5\xfc\x88\xbe\xc5\x99F\x89\xbc[L\x0cN\x07\x9e[\xcc@0\xe4\xe8\x04\xba\xb2\xc8\xf0\x17\xb1)\xf6\xee\x1b\x85\x16ir\xc2\xc2\xd4B\x84H\xd4\xa6\x1f\x97\x13v\xb2P;N\xbc!7\x8c\xc1\x83I\xd3+'
        b'\xa8\xf7k\xf1SE\x91\xf0.\x11@\xa3\r\x97\x83\xe1\xc0\xd1V\xf0_\x12oTT\x17V\x84\r\x83\xe7\x8e\xc0d\xa3\x0c\x1d\xa0s^\xb3]\x0c\x14/J\x16l\xe2\r\x91g\x8c]\x8d\x8aXM\xec\xfd\xcbG\xd5j'
        b'\x86\xa7>-3\nL~\xdf7H\x13,\x10\xf4\xdf\x1f,\xc0IPc\xd7&\xdc\x1c\xe3\x7f\xe9\x06\xc9\x8e\xc6\xb0Lo@\xc5\ns5\x91\x81b\x1f\xb7\x18\xf5}\x88\xdb\x90(X\x1f\x0c!\xe7B_\xfe\x84\x03\xf7'
        b'\xd7\xccr\xa7\x05\x93\x90z\x0e\xaf\xaa\x17T;\xd5]{f\xcb\x84\x0f~C\x98d`o\xb2\xd9\xb2H\x18\xbfP\x83\x17\x16\x8c4i\x84\x0f\x9b?\xda\x07\xde\x93\x7f?+\xd47P\xa1\xac\xd1\x06\x1cy\x03%\xf3Q'
        b"s8~\xbd\x7f\x01D\x0e\xe7\x9cx\xa1\x13,ln\xc7'\xe0\x8b\x9b~\x9c\xfd|^\x91\xb3\xbcQ\xfb\xa9\xe8\xde\xf2\x8f\x12\xff\x96\xf5\t\x80\xbb\xa4]\x08\xc0\xa9c\x19\xf8\x93\xffX\xe4\xdc1\xf0\x93m,\xd9\x82 "
        b'\xdac\xa7\xf3Js`\x81\xe9\xf3\xa1\xbe\xeevfm\xdc\xd5\xb9\x05\xe1A\xb2\x0c\xc1\x156\xd7\xa6\xb48d$\x85\xd1cJ\x8dh\xd4~\xdeQ\xa8\x8c\xc4\xc9)\xfc\xe8<s>\x1f\xa0=1\xdb\x13B\xf6\x8a\x11\xe2'
        b'\x1b1t\xc4\xd3>M\xe5\xe0\xd9\xc8:\xb1i\x90\x9f\xd0\x8f\xa5\xb3P\\\xca~\x12\x12%\x1c\xc1u\x91|_\xc0\xf2<\x0c\x9ex\x94T\xb6\x96\xea\x1a[8|z\x01\x86\t:\x1cL}\xe7\xe2\x80\xa0\xd3%9s'
        b'\xa8h\xdd\xeegH\x92\xc1k\x9c9\xfd\xcd\x8c4\xb8IY\x98\x90\xda\xa4\xee\xb0\xe7$M\x8d\xa9\xdafmO\xe8\x92)\xacz?\xd9\x88\xfd\xbfn#<\xfcT[;\x01\xe3\xbd\x01\x9f\xbc^Ae!Z\xcd\x85\xcd'
        b'Tf\xa8\xd8R?\x1b\xee\x8c\n\xf6U3z\xd71\xddP2\xe32\xc5\xa9\x97<\xca\xc4\x11r\x93,\x88\xe9\\\x163-e\x8b\x14}\x83\xab\x8a\x8c\xb3\xadB\xf5\x16\xc9\xdf\x1d\x9e\xc4\xa4\x02\xa5\x14^?9\xff\x8d'
        b'\xddJ\x16Nv\xa0}\x89\x85i\xe1\x9a\xac\xf2\xf3{W}\x1d\xc7v\x8d\x85\xc8\x82\x84\xbcR\x9e.8\xd7>c\xbc\x00g\xb8z\xc2s%\xd85\xb1x\xd0G\x83\x18$\xfb\xbck\x039\xbe9\x8dG\xe5i\xdc\xc7'
        b'\x90S\x16\x8cc6\xfc0\xfac-\x07bD\xf4\x8e\xd82Z|\xb1\x0f\xa7\x7f\x8aQ\xb3%j[\xc9\xdfht\xf8\x8cS\xc1\xc4d\xe6\x85\x95\x00\xe5q\xfa)\x92Q\x92\xe7.|19\xe6e\xa5\x8b\x89\x15\x8d\xc0'
        b"g\x1at\xe1 \x88i9I\xffu\x16\x16^\xf0\xc0\xad'\xc3\xc0d\x11\x8f\x1e\x00\x80\xde6\xd7\xf8\x04\xb7X\xdbo\x0b\x9eV\x0b\x17y6\xab\xde\\Wt\xdf\x9b\xbe\x8eLy\x9c46dc\xd6\xe2va\xa2\x0f"
        b'\x9e|)\xc7)4\x11\xd9Z\x0eh&\xa8\xe3\xe3\x17\x86\x08{\xca\x11\x05Q\xdbK\xfbQ\t\x1eN\xec\xe3p\x92\x96\x94\xbd}\t\xe3\xfa\xfa]\xb1\x1a7jN\xfeY\xbbe\x88\x0c!\x0e\xd7\xef\xa5\xfc\xder\x8aZ'
        b'\xba\xd6\xc3\xd6\xafB\x1bT\xc0\xb2\xb9\xc8\x8a\t!p#\xee\xfaF\xa5\x8a\xe9]vZ\x048\xa1S\x13~\xaa\xdfc;\xfdL\xfc\xba\x9fV\xb8\xee\x9a\xed\x97\x9d\xee\xa4\xe3\xfd\x1eQ\x07r\t\xa9A(>/\x7f\xeb'
        b"/\xb6knk\xbf,\xee\x9eR>=\x8a\xe85\xbdD\xc05\xf4\xe7\xbe\x82'69\xc6\x1b\xff\x96paS\xa0\xb3\x98\xcf\xe4.D\x1fU\xc5!R\r\x8e\xa0\xbf\x81(\xf0\xf1\xc1'\x02xp\xb6aA\xf4\xa5\x9e"
        b'\xfa\x0b\x93r|\x98\xf7z\xc0\xc73\xc8Dtc\nt\x7f\x17\x83\xbc\xdc\xe1)\x9cd\x86(\r\x8cs"ti\xc8\r\x84\x1bq\xf6`\xdd\xfb\x82\xfbk\xf41\x05\xfb\xac\xc2SH?1\xb2\xfc{ \xa7\xbb\x00\xa9'
        b'D\x9c\xae\x01\x80\xc2\x163\x8e\x87\xf2\xd3\xeex\xa3,r\x90xg\xb5u\xda\xc9\xf4^\x8eU\x8d\xd2\xb2\xfc\xde\x965\x91\xbb\n\x82\x1ft\xe9*r6\xe4R:\xb4\x11L\x0c\x96\x81\x0c0\xc8\x01\x8eo\xd8\x97K\xcb'
        b"\xd5g:\xc1\x0f,y\x00}\xdf@\x98\xcd_\xe7O,\xb8\xc6\xac\x1c\xe6\x1cs\r\x03e '\xe3\xa3c\xd0#\x8c\xbe\x9e\xd4to\xbd,\xf8hE\xc0\xb0*r\x863\x8a\x06D~G\x16\xf9\x88\xf2.\xcd\xc0\x14"
        b"w\xdd\x9b\xeb\x91=z^~\x07\xbc\xff'@\x07\x0bS\x0fH\x92\xfd\x95\x8c\xbe\x10\x93\xee\x18\xf5\xdb\xa8\x0ff]\x9d\x1af\xd3\xfd\x80\x04\xe7\xa9\xd3\xb4\xab\xfc\x1b\xcb$\xf0\x85\xcd\xe7o\xef\xb2lQ\x13\xbb\x91\xff\xe0"
        b'\x12\xac\xbcN\x1aZ\xeb\xd0L\xaa\xa0&\x8b\xe5\xc2h\xfc.!\xc3\x14N\xcaUag\xfa\xb7O\xb4c\xdb{b\x009o\xc9V\x96s\xaa<\xcd\xafc\x03\x9d\xcd\xbe\x92N)[\xf2\x1e\x12n\xe1\xc0\xf3\xa1\x9d\xfb'
        b'\x9f\xfb\xa9E\xfd\xabnT\xc3\xe3f\\R\x91q\xc2\xf5>\xae\xb4y\x8eLfQWL2\x10\r\xf82\xe1\xbd.\xdd\xb6\x86T\xe9\xac\xee\x13\x15T6eE\xb3\xfd\x80\x8c3\xe2\x8b\xab\x03\x1d>\xb4\x91L\x0f&'
        b'\xe2)\xa28\xa3\x07\x88\xc5\x7f\xb9\xcck(\xc0\xee\x8bB\xb7?\xa9V\x84\x16=N\xedz\x07\x8bK"R\xd9\xa0\x8b\xe3"\xa5\\K7\x89\xeb\xa8\xf0\x92\xe0\xcb\x87\xa8\xac\xe8\x1e\x9a:\xaeu\xb0Q3\xf70m\xaf'
        b'\xed\x16L\xdas\x1a)\x13\x7f\xbe\xf6I`\xb1\xe9\xb2\xd4N\xc5\x91\x15>\x17\xeb\x0e\xb7\xd1\x08[F\x9e|<\xdc\x1b =\x96\x01K\x81k\xd9\xfc\xe2\x17\xe5\xc6\xd3\x14\xc4_B\xdci9Zq\x14\xc5\xaa\xa3\xc1K'
        b'\xaf!!\x9dE]j\x00\x9a\xdc\x1c$Fs\x9dJ\xfbP\xb1B\xa9\x1cP2\x94\xd8\xd7\xd8\xb3k \x07)\xad\xc5B\x92\x00\xb9\xf08*\x9b\xedIqX\x86J(4O\x00\x93|\xe6\x98\xb9o\xa4\x90\x06\x8e\x8a'
        b'U2\x06\x8fq~r\xd4\x08\x9a\xe3u\xaa\xc0\xcc\xc3\xf5\xf7a\xb8\x90\x18\x14\n\xcc\xf9+\xed\xac7\xa4tQd\x81\xc9\x8164y\x14\xd6\xaf\x85V?\x96\x93U\x04\x0c\x17D\x1b\x8c\x96\xfa\xea\xa0\xbf\x91\x84M,'
        b'\xa8\xeb\xea/\'\x94\x7f\x83\x81\xc2\x1e\x8d\xf6\x92\nh\x1fa\x10W\x02oMg{X=\x05XA*\xdcV\xcd"\x99Ym\xb6\xac\x15\xd0\xb3\x1c\x0c*\xf1\x17\xccp\x11\xead\x07UXN\x00d\x8e\x03A#s'
        b'\xce,\x14\xf6+\x17\x0eWW8\xec/\xd3\xc0\xbe\x08\xa7\x07\xae\xf3\xbb>\x978cS#\xce\xef\xf2\xf3:\xf8t\x95\\\xee(\xde]\xe5\x1fG-$7\x87\xfd\xa1\xe9Au\x13\xd7/\x9e\xcc\xf8\xef\x84\xfcP\xeb$'
        b"x{\xc3?\xee\xf9\xb5\xb9\xf1\x86|I\x9b~'\x92\xf9\x89\xfe(\xfe\xdd\xe8\xa0\x83\xa1T5F\xe2\x01\xf151j@5c\x9c9\x0f1;8\x1cw_F\xf1)ES\x04\x8a\xd7$8\xb80\x94\x83HM\x8b"
        b'\x04\xf4\x87\xde\xd5Z\x1e \x05t\xc1~\xfd1,<\xa1\xd9s\x87\xf0?\\"\x90\xe5I0rlz\xb2\xef\x92l,3&O\x13X\xa9\x17\x1e\xa2!\x11a\xeeS\xa8\xd7\xf3%\xe23\xaf\xf8%\xbe\xde\xfe;\x90'
        b'\xe3\xa6\xdfz9-EH\xcbh7S\xb7\xe7\xf1\xd0J\r\xf4?6q\xc4{\x8d\xce\x19\x92g\x8a\x06\xccC^i\x16U\xce\xa38\x1d\xc6D\xcb\xa5\xa2Ng\x90\x8f\xa2\x03\x18)^\xf9Pb\x8d\x8b\x829\xc5\x18'
        b'\xd9\x02\xd6\xf9F^\x1c\xd8\xeb\x81h\x1c\xdf\xcc\xb1\x95\x0f\xcf\x9b\xfe\xd3\x07y\x82\xfb\xc50\x90\xde/\xf7\x9c\x7f\xe1\x8d\xe8\xd1\xc5\xf3\xeaH"{\x90\x98g\x83\xf2K\xf4\xb7\xe3\x1d\xfe,\x1b\x17\xda\xd4\xf8^\x03\x8a\x84'
        b'\xc3\xb2\\\xde\x0cf\x8bs\xf2\x1f\n\xec\xc6\xf2\x1e\xbed@?*9\x05\xe0\x93\x7f\x06\xb9B\x0e\xd9\xd8\xe2\xee?s\xac-\xe8\x05\xf0|\xf4\x1d\xc0s\xff\xcc\xae?0\x1c\x05\x89\xdcMeE\x8e\xeey\x0c\x10\x16\xd8'
        b'\x89|\xdf[\xa3\xbb\x04D\xd5K\x8b\xaa;_\xce\xd3\x07!\xfc\t&\xb9\x83\x01\x7f\xdc\x03\xf9B\xd5\x03\x1b\xd5P\x0b\x84R\xeds+\xaf\xea\x7f\xd2!`26lo?\xbc/ \x88)T\xa7\xfe+2i\xc8\xdd'
        b'x\xe0\xfc\xe9K\x83rrA\x01\xd4\xa0>\xef`\x80\xf9\xeb\xe6^5s\x9d\x9bZ_c\x13\x03\xaeH}\xac/\xc2\xe3,\xd9\xfd3U@\x0b\xbe\xbb\xb4xr\xe0\xc8\x9b\xd1NU\x9a4\rA\n\x19}\r-.'
        b"\x11\x7fV\xacpV\xf3\xb7N\xd642^c\xa8\x0eT\x88RP\xbf?\xb2\xf1\x84\xda'\x91_\xadTbI\x0e\xb2ria\x82\x86( \xee\xe1\x9ce2-\x02A\xb5\xdc\xb7\x17\x97\xe6}]\xa3\xdb\xa2\xff$\xe3"
        b'\x8e\x7f\x91\xc5\x05\x0e\x8f@3hN\xb4\xbc\xd6~G( \n\n9W7QF~\xf8\xa7\xe1\x1c\x02\xcd\x81s\xa3\xf8\xf2\x82f\x16$\xd8\x93\x19\xdb\x85Z\xd91\x82\x1d\xe0\xda\xed\xec\xad9!i\xd4Ge\xa1\xb8'
        b'\x8dK\x03,\xa1\x9dq\x08\xcd\xea`^\xe5\xee0\xc5\x9b\rd\xde\xaaA\xfc\x13\xce\xe8|\x98%\x07\xcf\xa4\xe7w\x10\xe2\xb2\xc6\xbaB\xe2\xad\xcbsRV\x03\xc1\xd1@=\xd7\xd9>\x9a\xc8.\x8a\x88\xffL\x9as\xc7'
        b'\x19\xd0\xaf\x80\xff\xca\x1c\xe1\xe1\xe1\xa4\xc5 \xde\xbc\x88H)\x92\xfeV\xd5\x9a\xaa-(\xb8\n\x96\xc9\xa6\xe9\xc9\x0c\xba\xb1\xdd\x91\xe7?\xbeS\x8f\xa2\xe2W\xac\xb0\xc4\x83\xfc\xc9w\xc9\xd8\xd7\x95\x90\xdc5\xc2",\xc5'
        b'\xd8\xd8\xab\xa9\xcd$\xd5r\x0ei8J\x84\x13\xbd"f~\x0e\xcf\xd1\xe0K\t\xeb\xe8\xa0\xcc|4\xc5(\xc4\x00\x0e\xef\x86\x0b}\x13[z-\xe9*\xc8\xee\xb1\xb7K\x06\xab\xe1L\x9b\xfaO\n\xa1\xb6\xf5j\xf5,'
        b'\xffq\x93S\xac\xca*0\xb0\x19L8Oe\xff6\xb45\xfb\x93\x076\xe7\xed&\x1e\x12\x9a\xe4\xdc0\xb3\xe2\xebC\x8b\xf2\xe8f/\x92\x94Y\x8e\xcc*\xdc[\xf8\xb3<\xc8f9L6\x1b\x1d\x1f\xb7p\xa9\xb8\x1f'
        b'P$a\xac\xc7\xc4\xbe\xfc*.\xed\x82{\xe1J\xec\x9a\xd2\x84[\x00\x12\xf2\x05$\x93zJ\x17\\\x0e\xdf\xcd\x0fb\x1fC\xb5\xf3b\r|w\xacx\x9eI\xd5<\xf7\xa3n\xda\x81g\xb9(\x9e\xcc\xf2G\x96-\x84'
        b'_\xa1\xe87\x8c\x95\xe2%p&\xaa\xbbH\x8f\xf4b\xa2d\xca8\xd6w\xeb\n\xaf\xd0\xf9\xfd\xa2\xcd>\xef\x0b\x054t-1\x94\x90\xd3~\x99D\xd6\x96\xa5\x96\x12\xc0\x9a\x8fi\xd0oTV\x12o\xe68\xda\xb8h'
        b'\xd4\xd32l\xda\x95\xad\xdb\xa9\xb1w\xa9;[\x9e\x88\xbb\xa7\xc2ZnI\x94\x183\xd6k\xebp\x05$\xf8\xed\xf0\xe4\xa8\xe6V\xd9\x0c\xed;\x07\xd8\x8bAD\x08\x1d\xa1\x1e#\xf5\xf0}\xe0\x12{\xa9%\xd2\xc7\xe3\xcb'
        b"\x16\x05\xb3\xe4\x08\x13\xcf\xa2\x12\xbe>\x1eg\x17[\xca*>J\xb3wI\xe2A\xc5\xdb\xbc\x80#-\xe9\xef\x9fu\xdb\x8d )\xee~eo'\xf9>\x85\x98\x13\xa6\x8cc\x9c\xe1\xc8%&2\x0f\xc1e\x18\xcaT["
        b'\xdf\xc8L\xacW\xb6{tk\xe6\xb8 q\xddj\t\xce\x8cVP,\x94LU\\~r$\x02z\x16}\xd4\xac\x80\xaba%\xef\x9a4\xcc$\xf1:\xcfR\x13\xc2R\xbf\x17\xc0\xa5\xb5\x19\t\x8d\xc5+\x88\x80\x87\xd7'
        b'\x01\x83\xfe\xa9{\x9f~\x05;\x10\xcdK\x02>\xb7\xe0Q\xc8/\xf5\xffB)^\xce\xf8|a\x7f,K\xc8\xefR\x9b\x1c\xbfm\xc7\xd6\xb0<al{\xcb\x93\xa0%\xcb$\xef\xbc\xa9\xed\xd9\xbd\xbd\x17Q\xdab)\x9d'
        b'\xbf\xc9\xde\x91\xdb\x0f\xf3\x05\xb4\x183s\xabd\xad\rw<\xfc\xb4\x9a\xd7\xc5\xddp\x14\x10\x9d\xa8\x9e\x9fko\x1e\x0ef9%\x95m<\x95S\xa0\xe7\xf0\x15\x11DE\xee\x1b\xff\xf1Gn\x19\xc6\xc1\xaf\xd7\xdd\xc3\xb9'
        b'\x1a8\x12\n\xceF\x94\xf0\xc7\x0edM\xb9\xec\x15\xca\xbb\x124\x01\x8c\xc3\xfd\xca\\\x89\xb6\xecC\x12\x15eb\x8b 8\x91C\x9a\xe7X4\x83\x1f\xaa\x1c]v%\xcc\x02\x0e\xc5{\xd0\xcb\x9b\xa0\xdf\xff\x01\x8d@<'
        b'B&\xb26w\x14\xc5\xdbH\xd7l\xa7\x9e\xb8\xf2\x8ez\xa1\xab\xcfL?\xd1K0\x97\x92\x18\xd7\xeb\x9cG\xc8\x1a\xdb\x9b\r>k\x04\x88\xdc)\x02A\xc1\xbd\x1b\xe2\x98l\xe8\xa1\x06G?\x1e\x98\x88\xf1|\xe1m\xf9'
        b"5Bu\x08(U\x1c\xdfZ\xc1TrQ\xbc\x1e\xa8\x06\x0b&\x99#>l'q\xce\x1c\x03\x8f\xb02\x8f-\n\xf0#\xc0fS=K\x1ebs\x84\xe8EB\x19\xb8\xb9\xd1\xe6\xf9\x86\xafy\xb5L_\xc9\xeb\xbb]"
        b"\xe2\xc3\x15\xcc\xbbj\xaa#\\\t\x92W\xb0\x89\r\xa8\xefA\xe1\xf9\xb2i\xcb>-]\n\x08\x15\x91\xa3'\xc7\xbc\x10;0\xf0(\xeb\xb8;\xaa\xbc\xe8.\x10\x88\xd1\xbc\xc7/\t_\x1f\xca+Z'\xe69\xe6\xf7\x7f"
        b'\xed\x9c_\xf21#P\x18\t\xf2\xea\x08\x99\n\xb6\x05nh&\xbdw\xdar\x8b\x8c\xcf\xdf~\xb5ok\xb4\x10h\x83\xd4&\xf0\x98\xfcq\xa3cV\x19\xb2\x83\xbf\xb4\xe8\x86Z\xa5S\x81\x921|\x7f\xfeu\xc8\xcbg'
        b'\x12\xc9\xe3\xe4\xe2\xe6p\xb3)z\x8e\xf8@e}oD\xf8\xdc\\\x822j0\xa3S\x97A\xd0\x9b,<\xbbTs\xcf\xc4\xe8F\xa3&\xee\xd00\xf0\xee\xdf\xfe\xce\xa6\x12\x99%(\xe5\x994I\xfaI^7.6'
        b'\xd4\xba\x87\xbe\x95WU~\xca8\x18-cC\x9b\xa0|\xcbZG\xe9[=1MP\xa2\x9fZ\xf4`$\xd4\xfe\x9f*\x8dEb\xf38\xd6\x1e\xd2Z6\xb7yB\xb8\xc9\\]\xfd[e\xc1<\x9bj\xbc\xf6p\xdd'
        b'\xb51\xf5.\xc9qCSG\xa2\xba\x97\xe7\x90\xce\xea\x91\rO\xa0\xd7\x9d(a\xf8e\x9b\x14\xaa\xe1EgA"\x8d\x94=\x9fAQ\x17x/(\xab\x8b\n\xaf!\x88\x0b(\x14\xce%\xef\x85\x91J-x\xfb\xe3\x03'
        b"<\xc9Bt\x98\xa8\xe8\x92yX'\xa0G\x9c\xba?\xaej\x8e\xed\xeaX\xc9b\x120\xef\x81\xfc\xae\xe5eK\x9e\xf8\xa5\xb1)\xebo\xaa3\xc6Ml\xe6i\x8bGRi\x9f\xf9X`\x7f^\x9cF\xfe)P\xb0d"
        b'\x07\r\xe7_\x03\xca\x0f2\xd8\xcfOI2\xf6\x0fG\xbep+\x98L6|\x14rBG\x85\xc3\xfd\xed\x84\xb2\xea(\x05\xa8\x81\xee~5\x04\x06Y\xbb\x00\x80\xad\x97\xa9\x98]B\xa90\xf9\x95\xeb\x8d;\xb4\n\x0c\xbb'
        b'\xabg\x02\xae\xa2\x96\xdc\x8d\x92\x10\xd6\xe5\xa5\xbe\x96\xe5%\xb5DD\xf3\x94\xf4ji\x9c\xb7Z\x06\xa3\xae\xe6\xc0\xf9@@\xf4\x12u\t\xff\xe8\x93H\xf9\x82\xb6\xdfn\xce\n\xfb@Y\xe59Y8\xbd\x97\r4\x15]'
        b'\x87l2\xa3k\xe8c\xdbq\x05\x0f:\x18\xb23\xe6\xefa\x8c\xae\xd1x\x8f\xcbN]dT4\xf7\x80\x15~\x81et \x04N\x86;K\xb6\x82\x92\xc7\x1d\xd7\xc8\xa1Q\x15P\x81\x1a\tlQ$\x81Q\xdb\xbdI'
        b"!\xab-\x87\xa2\x0bp'\x80Q\xab\xb9\x90\x8a\x11\xaa0\xfd\xf3\xba\xb3\xe1\x93\xa70C\x80C:\x02<?\xc2^\xcb\xab\x1d\x8d\xfe\xe1\x0e\xd17\xe0\xe7<\x83\x0b\xcd\xe1:\xc6(@Z=\x1a\xf7uP\x14\xa7W\x1b"
        b'\xe2\x8dsb\x06L\x84\x887\x99\xe9\xf2\x9a\xf2\xf7\xb9\\\xa9qG\x13\xac.\x0e\xad\x13i"`w\xb7fa\xcd\x95\x14\x8e\x1e\xc0h\xd1`\xf8e|\xf8\x1dH(\xc77\x90>T\xd6\x94\xd0\xe8B\xe6\xd8\xda\xa7\x99'
        b'\x9a,\xd3\xa2]\xbaE\xc1*\xa8M\xf8i\xf9\xfa\x1cE4g\x0f\xdf\xa7\x18\xac\x08\x1dI6\x7f\x80!\xac\xd1L\xd0\x06\x87H"\x00\x02\x1cG62*8\xe5\xf5h\x8f\x06D\xfd\xf9\xa7e\xb6g\xb9\xba\xfe3\x7f'
        b'\xdf\x11\x84R\xd1G \xa9E.\x0b!1Vc\xcd\x92\xa7*\x08\xfc\xcbF\x0b\x97\x18\x89\xb1\x82\x18\xe4\xdbS\x16-2w\t`2u%\xe6\xa1\xd5\x01\xfb\xec\t\xad\x08U^n\xa3)5~|\xf9\x9e\x02\xd5q'
        b'\x82\t\xab\xa6\xe6ry\xb1\\=U\\"\xc2\x045\x0c\x1eJ\xf47\xea)<C\xec-\xa9+z<yo,N\xed\x03E\xc7\xee8\xcb\xf7\t\x15\x9b\x1c\xbc\x9a\xd02\x1b6E#r\x1e\x85\xd6\x0fH\xcfWI'
        b'\xb1\xd7f\xe1\xdc\xd8\xa1\xc4\x8b\xe1K\xaa/\xf1\xca\xbe\x0bH\xfa\x10\xad\x85\xee\xfb\x89\x8f\x88\x10\xf8\xbb(\x80\x9f)~3\x11\xe9g\x0b\x18\xb5e\xdf\xe3\x17\x9d\xfbn\x99\xa2\x86x\xc1.\xdc`C\xd8\xccE\x0f\xf4d'
        b'\x95\x0c\x96\x8a\xf1\xb7\xdc\x8d\xec\x12A\xc6\x1b\xca\xb0r\xdb}\x9e};\xaa\xc5\x9c\x8f@]I\xd1=6C\x03(\x0b\x89N\x90\xfe\t\x19\xa6\xa3\xb5\xf3\x0b9\x92}\x82\x9f\x13\x0f\xb2FYj\x95\xe2#Z0\xe5\xfb'
        b'\xfd\xfd\x84\xf9M(\xbcq\x8a\xf2\xfc0,\xe0\xfd\x9aL\x07\xe8^\x12\\\xa57K0-\xe4\xa2\x079\xd6\xe8\x01b\x14F4\xdd^\xe5\xc01\xb7\xef%\x16\xf5\xe6G\x9d\x1b~\x12\x18\xac\x0c\x98\x061FX2J'
        b')\xeb\xdf\x88/\x05\xddq \xcb\x97\x80\x10\x13\xe3\xda\xdd\x84\x15 -\xca\xcb\xf8\xbf\xc9\x16"~]\xa1\x1c\x1a\xa9\xf1\x1d\xfe\x12u<\xd0\xe5\xa5\xaf\x89\x1c&\xf0Z\xc8m\xaf%F\x92\xc4V\x97E\xdf%\xc5\xf4\xdc'
        b'\xb8\x1aY5(\x8c\xc5\xe5\x99\x04\x91\xd6sl}{p\xda\xbc\xd7U\xe8\x9a\x88q\xc6\x08\xf7@1\x1cJ\x93\r\xd0\xddr\xae\xf7\x7f\xc8G\xad\x1a\x88\xfa\x12\xb1v\xa1\xfbB8o\x1e\x0b\xca\xeaC O\xc6 \xf8'
        b'd4\x988\xbf\xa0\x05H-c\xff\xe2\x94\x9df\xf1\xc4$\xf2\xd5\x0eU\xd3Q\xfa\xddz8>e,f\xdeq\x05\xf2\xf9\xc3\xb5\x83\xb5s\xed\xe053\xb8Y6\x02\x190ae\xb0\x14\xa1\x87S\x01=(Dt'
        b"\xe7A\x8b\x1bQ$\xde\xc06\xd9_'l\x1eo\x0c\xf9u\xbfG\x10R\xdfAv\xd3\x10\xf1\xf0c\xda\xab\xb9[\x8d\xaa\xd1\xdd\xaf\xfa\x1f\xdf\x89\xbf\xd3#\xb3\x0b\xb5\xa1\x19Y\x02\xa3\x88\xb0\xb2*\x13`\x1f3\xe0u"
        b'\xfah\xec\xf0\x9cC\xc2\xac\xe7\xff#\xcb\xd6\xdb\x08>\xa2\x1a(\x13\xcf\x02a|YE\xb9~\xd7\xc9j<\xb2P\xb6\xc5Nh\x03\xd4\xc6\xa2\x89z\xbc\xf3}\xaf\x84"\xa3[\x87\xb0\x9d\xea\x0bg\x85\xcbb\xf5\xc5\x01'
        b'\tn\x9at=\xa4X{F\x89r\xd6\x8a\x02\x12\x9ax\x1b\xb7\x07\x82\xa6\xe5\xd3\xf6PyIL\xc3\xf4\x10\x16@L\xec\xa0\x86\xd1M\xf6\x078-l\xe2\x0fgx\xde\x7f\xdb\x8c\x14\xa8A\xb6\xd3\xca\xf4~:\x9f\x83'
        b"\xf4\x80\xac\xc2W.\x01\xec^\xf9\xa0\xdadg\xb7{(\xa1\xa2\xdb\x93\x82\xc7t\xd6\xa0\xc6w[\x00\xa8'(\xba\xd6X\xe50B7\xcd$\x12F\xde\xda\xe4\xa8\x90\xf0\x18q\xe4\x06uTn<E\xd6z`\xca\x1b"
        b'|\x02\t(\x03\xaf\xfb*\x8e\xb0jA(\xd8\xa9\x91\xe4\xb6I\xdb\xabq\xbaV0\x0fI\xb2\xc4a\xa0\xcd<\xc7?\x05\x1d\xcd\x06\xf4&\xe4Z\xaaR\xbf\xb9Q\xa2\xb6\xf07\xed<k\x81\xab\xca\xe4\x83>\xa0\xfa:'
        b'n\xf1\xf2j\xa8y\xe6\xd2\xd8\xcd\xbfpJ\x8ee0\xf2bX\xe9\xb3<bv\xd0\xc6\x192\xe4\x8b\x8dv\xe0\xffR\xdb\x8e\x04\x9b\x92%\xa8\x1as\xf9\xe3a\xc6P\xe1<\xc7\x93\xdc =L\x84\xb2\xe6Ep\xed6'
        b"\x10\x84\xb2\xfd\x82%\x8c\xf40E\xa3\\d\xe6\x01\xb1\x98'\x08Qz\xd5\x86I\x01o\xe1\x86Nc3\x8eI\x10\xc0\xb4\x19\xb16\xa3W\x1dq\x9f\xc8\xcd\xab\x19pt\x05O\xa0\x8f\xf0\xa2\x03\xa6\xfd\t\xa9\r\xa0\x98"
        b'\x81\xe1\xbbl\x92\x07O\x97CU\x1b\x85)\xcao-9\x0cB\xe4\xdf\x86\x98\x8c\x85\xf2\xb7\x8b\xce\xb7CbR\x87\xac\xa2\xd9Q\x0c\x19\xc8\x806\xdc\xf3$\xa1\xd7\xeca\x1b\xa1\xfc\xf5}~M\x9c\xa9\x9a\xa1\xe5+\xf0'
        b'\xfc3\xaa\x8a8F\x15\x9a\x19\x1eAp\xfe\x8d\x12\xd3Ie\xba@F\x94\xf0\x91\x18 \xab)s\xbc\x06\x10\x05\xa9\xdc3\xaf\x07+\x98\xc5\xa1\xad\x8a`\xf4pB\xea\xe7\xb0\xb8 .A\xbc\xb3\xdb\xb0\xab\xc4\xa8^\xeb'
        b';\x85-\x04\x00,,\xeb\xeep\xb2\xd6\xb6\xb0\xa2Uk\xc6\x82\x8ev_\xec\xdb0\xd5\x81\xc0Xb5k\xa2\xe8\xe1\n\xf6:\to\xd5\xf71`\xb9|\x02K\x97\xedP-\xbd\xa4\xe8\xae\xd7\xb2\xe8:|\xb4\xa7\xd3'
        b'\xfa\x12\xbb\x0e\x9ak\xb1Z\xd9F?A\x04;\x8f\x90\xddN\x9b\xe7\xbaCx\xf7\xa4\tH\x97\xb9\xfb\xa0\xce\xa0\x1a1\x92q\x95\xd2#Y\x14+\x1a\xa6Lwu\xb4\x19\\\xab\x906\xd1\xbe\x0c\xd6ybVK\xba\xd9'
        b'\x19{1\x98k\xa2xZC-\xfa\x12\x96`\xa5\x8f\xccg\x05f \xc3\xa3D\x8b-\xd4\xe8\xc0\x17^\x19\xc7\xecdW\xb9j\xd8\xc3\x11w\\T\xe8\x9a!\x97\x84Cf\xa7\xa3\xc0\xc3|6\xa5y\x04\x08\xe1\xb0\x9f'
        b'\x08\xf9$n$\x02\x01\xadaoX$D\xf8\x8f\xf5\xef\x012\xd0\xff\xc6\xf9\x88m\x99\xf9\x80\xaf\xebc\xdc\x12\x17S\xe1\x93\xfbJ\x82~\xd7\x0c\x9a\xc5\xfc\xc9\xe8\xdb\xecw!0p\x188h\xb4\xed\xf0\x8eQ\xb2\xc1'
        b'Gi\xf6\x06\x03Ln&\x9b\x88\xa5\x99\xaf}{\xb3\xa1 @\x8c\xe0\x9a\xa9\x88\xd7\xea\x1b\x04\x10\xefl\xe2\xee\xbf\x90$\xceH\x8d\xbc\\K\xff\xaeb\xc4D;Y\xbfEmx\xb8I\x1et\xb8J\xcc#S\xe1\x80'
        b'\xb6\xb6\xd9 \xbdl%\xbe:\xb2\xe9.\x9e\x8a\x08\xaaP\xb2t\x0f+\xdf\x8b\xfc(|\x8d\xbe%\xda\x88\x1bX\xa0u\\v\x01\xa1_\x99\x8e\x14\xb5\xd6\xdc\xb1d\xabD\x95\xf4\xad7\xf1:G\x1b\xe4(,\xbf\x16\xe8'
        b'kLV~\xc4\x96\x93y\xc9\x90\x17N|\xc9\xb6\x9de\xf9]/\x8f\x026q1\\v\x92\xd7\x087\xa9\xdf"\xa3\x822\xf8a \xb3\xa6wi\xb7\x02\x94\xd4\xf6&rD}\xbb\x0f\xaf\xcew-\x0f\x95b\xf2\x18'
        b'\x8a\x05`\x9a\x05.c\xeb\x86Q2\xdb*2\xa1\xe5)a/\x1b\x9f\xdc\xc6\xa5\x8d\xcf \xaf-\x1d\xee(\xfa\xdb\x0e\x80\x97\xaa]\x17k\x7fyv\xc5\xcd\x16\xa8#\xb7\xc6\x81\xdaQ\xa6\x167\xdf\x15\xfbS\x90\xee*'
        b'\xdd\xf7[\x91\x07\x99\xca6*\xfa\xe4,&f\x08\xd4w\x81\xe6\xd1\xf1,\xdf\xf2\x8ca\xdb(\xbfW}\xb6\xc3q~\nF\xdf\xe0}iV\xbb\x90\xb0\xb7\xff\xf7_x}\xa8\xc6\x9e\xee\xd2{\x83\xc0\xc9\x82\x9f\xb6\xbd'
        b'\xd241ysB\x10\x0e\x1e\xc7WB2/0Jo\x1dy\xe2\xa3;\x00\xddL\xaeo\x90\x15\xb4\x9b\xd8\xdaZ\xfa\xa3\x01$e\xcc\x13Sd\xd1L\xb3\xa1\x14\xe6\xb6\x9d\xbbf\xe4\xb2\xd3\x18u;\xc0\x96\xe8H\xdc'
        b')\xdc\xced\xdc2\xb7\x9d\x0c\x16d_\x14X\x90\xee\x9e\xa7fC\xfd\xcaIq\xb8\xde\xe6\xaf\x04\x91p\xfc^\xf5\x90\xa9\xb7\x94\xeeW\xb2\xcd;\x9a1\xe4\x14NV\xf7\xa3\x1f\\Q\xce\xc3U\xb6Ff\xd2\xc5\x0e+'
        b'\x89\xdbAL\xf6y\x17\xc9\x8b\xdbe\x14\xafX\x9d\x9e\x92\x1d\xf0\x04\x1e\xa6\xcf\x86\x9bX\x93\x82\x9c!Z\xea\xeb2}i\x8a-\xab\x9dOM\xd76}\xf1\xf0\xc9\xff\xfeOg\x1b\xebH\x0f\x08\x0bM\x940 4\x9a'
        b"\xdb\xcd\x81\x1d\x1f.\xe3&\xdeW\x0c\x17\xf36\xe9/\xe78\x03\x8e'\x12!\x04\x0ct\xd7\xa6\th\xbc\xea\xde0D)\x88PX\xed11i(\xee\xe5'\xac\xd2\x81tK\xb1\xa6\xb9\x89\x0f\x14\x0b\x8b\x8eq\xad\x99"
        b'h\xa0iw8"\xd3\\\xc1\xb3\x9d?U\x88\xde\'\\\xcd}\x1e\x83\x10\xe6[\x93\xc0\xa8\xb69\xdcK8.\xfe\xe3\xc8\x8d\xfc\x16\x14\x87\x10a&\xcbw#\xcd\xd4\xd4\xd8\x82\xd6!\xa2\xfaL\xfe\xcc]N\xee\xe5\xc1'
        b'f\xf5y\xf9\xb3h\xa0\xea\xe2\xa9\xc0iBC\xaa)\xf1\x1b\xb2\xa2\x93\x08\x87d&\xffG7\x11\xdd\x99\x9a4\xee\x82\xcb\xde\xf9m\xdb\xd8\xdc\x80%\xa7\xf4i\xd1\x82h\xfa\xd2\x19O\x85\x08\x03J\xcf\x9f\x84h\xd5-'
        b'6\x18\xbej<K\xb01\x0c=\x98\x7f^T\xb9\tD\x1c\t\xbb\xef"\xd0\xa9\x8bQ^{W\xf6\n\x14\x9b\x91s\xb8\x89\xe1\x9f5\xf7_\xbc^S\x05\xd1\x8a\xdfz\xb5\x07\x00\x0e\xc2\xb1j\xe4\xee\xe9=\x8a\xb6\x91'
        b'\x99\x9d\x94\xee\x82A$\xca%\x18\xec\xf0\xbf\xe81\x19o"?\x1ba!\xb1]\xe8\x92vU\xf7\xcc\xf4\x9b\xbe\x15pS\x14:\xa0\xb08\xc3R><\xc1h\xf2i?\x98\x1f\x04\xc4#q\x9c\xbe\x81\xa4C\x8eHS'
        b'`m\xff\x05\x87\xbd\x9f\x86\x1cC>\x1d\xfaOh\xf8\x12:\xf1\xb6\xee\x89\xa1\x0c\xbb\xb3\xd4J\xbd\x88?\x92\xa2x\xcf\xea\xa3\xe2\xc1\xa8Q\xc3\xdf\x8c\xff\x1e\x97_\\\xd3\xac\xab\xf2\x85\xd5*\xdb\x88Y\xfes\x1e\xd8W'
        b'\x1b\xb0\xde\x04\xeb\x13L;\x17NE\x92s\xd1\xc8+\x99K\x1e\xfb\xf0\x80\xa6ASk\xda\xd5\xd7\x16\xf2\xefiH\xe2\x1f\x83\x8b\xfa\xfe\x0fSG\xc8x\xf5W\xb5\xabI\xca\xd5\xa4L\xd0\xf4?\xcc\x9f\xc1\x97\xff\x05\x84'
        b'\xa1g\x07\x91Q\x9a<\xbd\r\xcd\xbf\xa6ku\xe3\xda\xe1:8\xba\xeeQ\xa4\xc4\x8b&o\xdf\xf9\xc5\x80k^>D\xa1j3\x81\xc6jZ\xe2\xbb\xad\x08"(\xae\xbc\xc2\xc2v\x9e\xcf\xd5\x19\x84\xfe\x0b\xc9\xae\x94\xf2'
        b'\x97f\x81\xb9\x8d\x99\x9a~4\x0fa \x0f\xd3\xab>oW\xcc\xb5\x8eG:\x1d\x05\x8b\xbe\xd7\xf1\xeeOH\xb4\x87\x9eee\xccPs\x81\xef\xffY\xa1\x92\x16 \xdaN\xad\x85\xf1\x8e\xd4p3\x00\x8c\xa7\xe6b\xfbO'
        b')\xc1\xacW&\xd3\x05\xa0\x1b\xfa\x00\x19J*\xdc|\xfb+u)\xe0\xe8\xbav\x1cf=>`zEw\xfa\xdfJ\xd2\xee\x96R*P1v\xe9\x9d"\xb5L%q\xfa\x90\x0f\xb5\xdc\xd2\xc2\xdb\'E\x88Oy\x1f'
        b'r\x1d\xf9\x0c\x16\xf2\x05t\xd0\x81\x9b\x80~P;<\x9eh\x1a\xa0\xa4\x8c!M\xd4\x012\xbb\xecw\xe2\\\xec\xbd\x83\xe3L\xca\xdf\xc6\x93\xba\xdf\x8a\x06H\xed\xac\xc9\xb6p\xb4\xfe\x15\xbe9\xd0\xda\xfa\xe7\xab\xb1zS'
        b'\xeb\xca\xf7\xb1o\xc5\xdcQb%s\x10n\xb6\xcaC\xef\x7f\x96J\xce<\xfa\x94\xfd\xa0\xc6\x06pc\x13\xfcT\xe8H\x08S\x9f\xf0\xbc\x04u\x8d}\xd7\xdb\xdd6\x00\xa0\xe3~\xd5\x1c\xeagp\x98\xcc\xb7$I\x94\xd9'
        b'>\x8a\xaeE\x95\x0f#\x1emBv\xed\x8f\x93E V\\\xdb\x86\xb6\x94[\x984\x83\xb2"w\xd5CC\xa8\xbf_(~\x05\xf5\x84H\x12\xea\xc4\x15,\xab\xa4\x8e\x06\xb1\xd3\xdcK9\xfb\x98Xa\xe7G;\xc9<'
        b'\\\xfd\x17JQ\x9a\x98>\xab\xcc!\xb0\xdc\x94\xcc/\xda\xa7\x1f)>l\xb5\x06\xcb\xc355\x93\xa1z\xf4\x80\x92\x1d\x0bBQ\x8a\xae\xcf\xbf\xd6|\xb5\x00\xaf\xdf\x8a\x12)M\xe4\xe6\xde\xb4\x94\xb1\xfd\x17;\xa3\x81+'
        b'\x1cL\xb6\x83\xf64\xd5\x1fq\x94!\x89\xae\x18@\x0e\x821\xde\\\xcc \xc6i\x9b\x9e\x0fU\xc8\xe6\xc9>\x1e\xdb\x91\xcbZ\xca\xf4\r\xb6\xf8\x0ce\xda\x81\x07\x84\xca\xff\x9by\xc9\x05q\x9c\x80\xe7\xbc.\xdd\x92=Z'
        b'pr\x08w\xae\x98\xbd\x16,\x10=\x8aSV\xf1Ob\x84\xdb\xce\x83\x84\x9f\xeat\x1c\xfac\x97B\xcena.#\xe0\xfe\x8a{c4b\xb8:\xd6\xebJN\xbdf\xa1!\xcb/\xca\xb0\xeeS\xe6\xb0\xac\xf6\xdb\xe6'
        b"f\x13l\xbb\x1fl\x98hiU\xf7'.\x91\x16\xee\x8e\xc7\x92\xc0\xf6\x9e\xc0\xdb\x01\xbc\x84_\xe7*\xe1\xe7\xd7\x13\xe5^\xb8\x7f\xd2\xab$\x1dS+t\xc0\xb1\x89dB\xa3\x8b\xd25&mN\x80=S\xc0\xe7\xff\xab"
        b"pA\x87\r@\xb9\xf2t\xf9P\xf5\x07\x82[\xf2\xd1;\xe7\x14\x92\xca\xc8\x0c0\x1f\xb2\x048\xc2\t\xd3\xa2\xb8'\x04\xe8IT\x18\xb4\xd3\xddR\x8e\xc5Fd\xe3\xc7\x0e\xf8\xd8i{;\xafK\xcb6\xc8W\xae\xefq"
        b':\x8b||\xa7m\x1bw\xc3\x99\x9fh\xc0\xcd\x10O"\xd8\x1c_\x85\xc3m\x8d\x9eC\x8aF\x9d\xfacZdE\xbbR\xe37,\xe9t\xbf\x0b\xcb\n\x1d!G\n\xbe\xe9RH\x06\\\x01e2\xe0\x81\x16C\x9e\x81'
        b'\xf7\x8ab>\xdd\xf07q\tO\x1f\x8aI\x91\x07:\xe3\xf8:\xdb\xd2\x1cc\xe4IY\x02\x0e\xc9\x9eW\x98z\x9c\xc9TLV\xae\xfe\x86\xd8\xf2\xadV\x8f\xda/\xbd\xba@\x07\x90I\xf4\x8d2\xf9\xa6,e\x16\xcc\x95'
        b'$C r\x7f\n\x16\x9b\xbd\x12\x99,k\xf7\x91\xa7\xc8"l\xdfM\xe7\xf9{5\xd8\xf8!ya\xa7\x02 \r\x08\x07`\x10DD:\xb1\xff\xa9\x91Ly\xc2\x96Q\x10?\x1f+\xa1\xb6\xb5\xe7\xc3a\xd2\x05\x1a\xec'
        b"\xb1ad\x81!\xb3\xce'\x12m\xc6\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file"
        b'__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
