
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\t/\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xc9.\x00\x00\x00\x00\x00\x00\xc6\xb1\xd2\xf6S\x82"\xa2]\xa4\xb7\x89\xb98|\x13\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC'
        b'\x15Z,F\xdc\xcc~\xc2=\x19\xb6\xc1nt\x8b\xe8\x13&*\xe0\x06.7[P\xf0\xe9S\xb0\x88\xb4\x89\x07\x0b\xe1\x85\xe3\x13\xd3\x8f2\t\x14\x00\x97tF\xe1H}\xaf\xab\t\x83\x94\xcdP^\x1co\x80\xe6\xa6\x1b'
        b"\x9aN\t\xa2\xf9\xe9'\xdfb\xf2u\x8c-\x1b\x02\x8a\xc7\xdbX\x03\xff\xea\x9f\xe5\xcdsx_\xc6-\xe2\x91\x02Q|d\x81\x8a\x88#\xcd\xab\xc9*\x82\x80W\xf9kDs-\xf6\x16\xe7\xe3>X!Vto\x14\xc8"
        b'+\x9fo\xb2\xe3\x07\x82B\x8d%\xc0\x9d\xf4\xf5&\xa2\xcba^\xd5a\xa0\x8d\xa4\xce\x10\x87a@\xd9\xb1}.yi[@m\xa4\xeb\x13\xe9\xa6[L\x94\x1es\x1f!\xb9\t\xa2\xd6\xb9\xb1\xf7\xbd\x89\xd6?!\x81H'
        b'\xcc\xb6\xf4\xb4c\x8cV\x08\xdft\xb3\xa1\xadre\x1f\x80\xb3\xf3\x18\xa3u\xc9Z\xb6]\x9aU\xd8^AD\x02cx\x18\x00\x8ekP\xd2\n1\xb4\xf6\xbc%\xcc\x0c\xa8,a\xe3B\x9c\xc4\xc6\xba\xf2\xd2l\xa4\x05\x9f'
        b'\r\x19\xf8\xf3!\xdb\xd0,k\xa5<C\x0brm\xedM\xdd\xea\xc4NT\x12\xd1R=\x91K\xa0\x1d.W\x1c\xf2\x1e\xc7\xcc\x8d\xb4x\x96\xca\x824]\xe7\x17\x8b\xdf\xe1\x91^r\xaeU5C\xb69\xdfp\xb6M\xeb'
        b"\nW\xdd(p\x88\xea~z8\xf5\x9b<d\xae2\xb5\xed\t\x83\x94H.\xe8\x9a\xdf\x1c\xd4\x94\x93\x11'\x97I\xee\xb9*\x02\xc1\xec\xc0\xbc'\xd5\xe3\x19a\x84 \xb3zmW\x801%\xbd\xb2\x9fbi\x1e\x11O"
        b'\xbd\xa7K\x08\x1a(Dj\xf2\xd4\xb9\x9a\x98\xe0tgQ\x94\xc9\x1a\xde\xea\xe4uc\x10\xe7\xa6[4\xd1f?\x17\xb2z"\xe4yN\x87\xd7D\xe6\xaa\x88,\'\xaf\x02\xffxHi\t\xee\xf1\xdcn\xa1\x0e\xb4\xed\xb0'
        b'\xab\x8a\x93\x1d-\xdc\xd0\xc4\x14>X\xa5\x8e \xb4\xc747\xbb{ \xd7\xc5.\x8a\nx\xea\xa4\x99X\xbel9\x8b\xc3\x91\xe2\xf6{\x97O\x15\xc6i\xb8m;I\x00;\xdfG\x94\x03=\xc7R\xeb!\x11? F'
        b"\xd4\xb1,\x03v\xb08'4\xff\xd5\xf7u\xf9\x0f\xc4Lh<\xfc\x8c>DQ\xdc\xb3\xb5\xcf\xb9#\xf1C*\xee\x8f\x8f\xb4\xa7y\xaf~\x1a}=\x06\x82,\x89D\xe4\x91 z'\xac\x06\xc1p\xbb\x0f\xfa\x8b\x9e\x96"
        b'\xfbk\xf4\xa8\xb5{X\x0e+\xdd\xe1dX\xbd\xc2w-n\x95\x8c\x90\x96\xdd%\xc6O\x91\xd8_\xe1|"\x94\x9c\xd9\x90<I\x81\xf2\xfc\x91\x84\xbe\xd1\xea\x13\xd0\r\n\x07\x89\xd8\xa0\x11.\'/\x7f\xd4\xdc\x18V\xfb'
        b'\xc0\x01w^\xf5z\x11^\xbf.}\xe7\x19\xa5\xfcM\x8713\xbe\xb3\x06\xc0L\xe2X\xb6\x13\x82\x02\x9b\xcaIx\xde\x12\x8e\x89\x0e\x83D%\xcc\xd2\xa0\xa6|,\x12\xa2\xe3v9\x9a\xfd\xa80X8\xbb\xe8\x7f\xae\xf4'
        b'V\x9aD\x0c\x87\x9b?\xf6sz\xf0v!\x11?h$\xc8\xb0U43\xa5\xd0\xechK\xcaU$\x01?\xaa\xa8\xcf_\xa3;bU\x99\x10\x7f\x08\xdba\x8d\x15\x82K\xc7T\xfc-\xd2\x04\x0c\xce7{\xb5k\xaf\x97'
        b'\xc0\xdeN0\xd5\xc73\x0fJz3\xd3\xce\xe4S\xcf\x9c\xd7X<+F\xdf+\xb0\xd3\xe4c\xe5Zu-=\xaa\xd3\xa1\x15\x9b:\x11\xcf\xb4fF\xad<<\x9a\x19\x8b\xde\xd6n\xf9f[@y"S\x81Z\x97&'
        b'\x96|\x9e\x06M\x1d\xaa\xb4\xa0\xe6\xc8S\xb1\xe2y]\xd34(V\xe3\xd7;6\t\xfd\x81\x15\xaf4\x80I\xcet5\xb3\x82\x14\x8a\xd9\x99\x93\xcc\xee\xf3<\xd1\x81\x1a?x\xe9;xH\xba\x0c\x13pdgp\xbd|'
        b'~Y\x10{\x98\xe0\xb1\xe8\xac\xd5\x85\xbd\xdb\xce(\xd7p%f=\xa9pG83\x02\xffE\xfbI\xea\x0c1\x02\xa0,\xf6vC\tg\xf0\x05%{t.*\x07\xbf\xd4\xd1\x8e\x83\xa5\xdb\xe8\x86\xd2a\xb55\xc7l'
        b'\xd1\xab;\x90\xb7\xe8\xd1\xce\xbb\xf6^3H%:\xd5\xb4\x17\x03\xe2Q_\x91_\xfeEbx\xac\\\x95\x8c\xc7\x0c\x9a\x1b\xaai\x94\xd21\x8b\xbd%\xc8:\xb3\xd7.my\xe7\xf9\x01\x11\x02\x85\x9e:\xb6\n\xd1`\x92'
        b'4\xd0\x1a\xaa\xe1m\xf1\xa9\x90E*\x0c\xcf\x9c\x9b6W\xad\xe1\x02\xc7\xf4\x1c\xfc\x8d\xbcXg\xf2a\xbc\xcajCJ\x1e\x05_\xdfq\xa6\x17\xdd]\xe0\xb0CQ\xf7\xdf\xab\xb5\x89\x1e\x80\xbdW/I\xb1\x83\xf3\xb6\xa6'
        b'5\xb3\xd9\xa8`\xa7\x95\xbexo\xc9\x84\xce_\\\x96l\xc5\xc5\x9d\x86\x8d\xd9r\x15K\nRj\xd1\xdb4\xf8\x16\xe0\x13&7Sp-\xbc\xe0\xb7\xa3\x1a4\xe9\x91|Je\xaeObh06\xa7VR\xa5\x05\x13'
        b'_\x1e\x13\x7f^!%\xca\xebM\xe5\x07\x1aI\xffmZY\x1b1\xb1\rY\xc8\xf9\xd4\xc3=\xe8\xb9\rr6a\xf0\x06s\xc7\xcbdc\xbbQ:\xa6l^\x13\xa7\x1dN>\xe2\xf4\xb5\xf7\x1d/\x11r^\x83\xd8\xca'
        b'\xd9(\xd4\\\x1e\xe0\xb2\x9dF\xe9\xb1,\x08\x9e,\xd1K\x1b0\x9d0\xc7[o\xe3#\xe2q\x96g\x88\xf8\xb9\x91I\xce\xd5\xe5\xc3a\xc3\xddv\x8cb\x88\x8fim\xc2E+\x8f*\x030\xf67\x82,\x87|\x88\xc5'
        b'\x01"\xd23\x03\xfa\n\xa2\xea\xec\xd3,\x10\xa9\xd6\xdd\x9f\x97\xfc\xa5\xa3\x80\x90\x08\x163\x84*\xd3u\xc3\x04\x8f\x10b\x0bE@J\x1f\x05E\xcdW\xa9\x8aM8\x11\xedX\xef\xe8=\xfd)\x9c\xa5\x9e\xde\xbf\xb4I\x0e'
        b'\xc4\xf1\xabXS\x08=\xe2c\x8f4l!\xf0\xf8\x119\xeft\x80\xa9\x80\x96![\xc8\x7f}\xb0\x86\x8d<=u|\xf7\xc4&\xa9\x15R\xe4\xfe\x9a\x92\xc9\xde\xe5\xda\xd4\xc3\xb5\xea:W\xd6\xb7\xb5\xbe\x93\xf0/\xfcE'
        b'\xb8F\x14C\xd7\xc1\xca\xdbD\x8f\xb7\xf5\x80\xad\xfd\x1f\xcb\x17\xb0\xd0\xee "g\x91\xbdwY\xea\xb9\xc4\x99\xe55\xa2+qh\xc6]\xb6\x14\x8e2\xe4\xbff\x89D<\x06\xceB\xaf\x8d\x1d\xd0b*\xa9\x16\xffs\''
        b"\xb7\xc2o>&;\xa5\xc28\x03\x7f\tg\xd5\xd6\xee \x10\xe2\xe4\x0f}\xa0%\xb6G\\\xd2\n\xa4\x0e\xfbY\xff\x83\xe1\xdb\x84\xac\xf1\xf0\xc7\xbc\xee\xbf]\x12\xcdr\xc6\xa9\xde\xea1\xefGJo\xeeH!\xe4'\xb0"
        b'\\`\x8f\xbb=\xe0`\xc5[\x82\xfaJF\x15\xf21\xbf\xde4\xf7\xe6\x1e\x82\x83\xe1\x05@\xabLE*\x1b\x1f\xdd\xa3E\x99\xd3\xa5\xcc0\xe9zx\x90\x04\xb2l"\xe7\x03\xdb\x1e\x10G\xf8\xed\xd9\xac`\xdd\xa1\n\x98'
        b'\xbd\xf2\xdcg\xfczyM~\xf5\x92\x15~x\xf9ora\xe2%p,\xcb\x9c\x8b\xf5\r\xae\xdcpL\x1a\xc90?lm\xcc\x04\xb3j\x0f\xe7\xab\x04\x01yC/o\xfb\xd4\xa8\xd3\xe9k\xc0\x12\x05\x16\x17$\x08@'
        b'\xb9\xe7[q\xad\x1f\xcf\x13\x7f\xf5}o\x8c\x18\xe7\x8c\x8c\xc7\xae\xb6i1\xb0\xf5\xeeW(k\x0bB\xcf+\x0f\xfd\x1c(\x04\x80Ig\xbf\xe0\t\xf9\xa5\xa3{\xef\xcf\xbc\xf5\xfaD\xf7\xf7\xf3\xe8\xf3\xca\xd8\xc2\xf0\x9b!'
        b'V\x8d \x0c==\x15\x80L\x02\xc8\xccy\xe3b\xf2ysr\x90\xa7\xabK\xa3\x147\x0f\x13\xa3\xd79\x8dtLO\xc0\x02\xe5\xdd\xd0\xfd\x0b\xe9\x84H>}=+c\x1c\xc1\x97\xf2\xef\x92|\xaa*\xf9\xe5\xd5Mi'
        b'\xd6P\xe1]\xbe\x0f+\x904\xf7{\xaa\xda\xd6v|C\xcc\x97\xb5#\xcdd\x8c\xd8\xee\xe2\x00C\xe2\x1d\xb0.?\xccX\x86\x16\xaa\xfe\xb3\xd5\xe0,\x1c\x01\x9f\xf6S\xfa%\xac\xed\xbc\xc6;\xb5\x1d\x1c\xa1\xd0\x90h\xa0'
        b'"\x81\x923\xaa\xdd\xa9\xfb\xd5M\xfauv\x82\xafw\xb0\xbd\xd7\x9fCO\xc0\x17|P\xaf\x14pze\xc8*\xf7\x1a\x1a\xe3o\xd2\xbe\x89#\x06\xe9\xb8l\x9a&\xa4\x1c\xbc\xe8\x9f)\xb7r-\x15\xd7\\\x1d)\x98\xc7'
        b"\xc0\xeb5\xbe\x98\x9a\x91=\xe3 \xe5\xd1y\xf0@3%~,m\x0f\xdb\x1e\x02Sf{\x9e\xfb\x04g\r]\xe8-\x87+S\x84'\x02\xb0\x94\xdf`c\\x\x86\x1b\xbc\xe4\x97\xc3\xc6\x97\xf8\x87\xb4\x86\x8eD\x06X"
        b"\x14\xd2\x92\xbf\xa3\x9f\xd1}a\x93\xd8a\x13\xb5\xc4\x1b)\xd0\xd7\x9fX\xe0\xfa\xe1)\x0cj\xf3\x9e\x1c\x81%\xc3F\xc9\x0ej+K\x85;\xd8u\xff@\xdf\xc6\xa5['\xca\x9fJ\xf4\x1f\xff\n3e\xdf\xc7\xae\xd4\xe8"
        b'h\xe6\x18\r\xb9\x02\xc8\x03\x91:;\xb3\x00\xcf\xcd$\xda\xc5\x95\xf4\xb1LhI\x12\xca\x1e\xb5\x15H\x02\x00\xee0\xcd\xec\xa9\x15a\x9b\xfda\xd1\x05\xd3\xbbo\x82\xce\x1f\x85\x89\xea\xcb\x99\x95\xc9\xd7\xffr{1\x8a['
        b'\xb8n\x06\xa8\xaa\xef"U\x05i\x9a\x9f\xfe\xa9\xdb\xf7\x08e\xbbm\x15S\xc6\x1e+\xaa\x9ab\xcfp\xd8\xd4P\x97\xefy\xe2`(\xce\xb9v\xe9]\xb0Y\xf7\xa7\xdc\xb5{\xc6\xc7.1\x87\xbf\xadR#\xa2\x08\x1e\x9d'
        b'\xcfI\xd9,Q/*N\xf8j\xe1\xfc\x96]\xf4\x19\xf0\x10\xcf\xae\x00\xa4\xdahd\xe7\x82\x1a (\x9c\x99\xcd\xc7\x8b.\xd8\xb0}\x98\xcaE\x9a\xa1F6\xf8\x86M\xcc\x9a\xea\xf0\x8c\x1eA\x0f\xd4\x0b\x98\x91\xbeO\xfa'
        b'\xf1\xf8\xab\x964+\xb7\x17\x19\xbc \xce\x06\x00?\xe1\xe7Y}D-e/\x9a\xae\xfb\xb0(\t\xa5\xd4\xe7|"\x84e&D\xb8\xcb\xf8\xfa\xa3\xc1=\xaa\xdd\x01\xc6Hn\xb2[\xfe\xa4\xca\x19\x03\x91t\x80o|%'
        b'\xa9\x1f|\xf6>\x82\xd8\xf9\x02`\xf5k.\xf1"J\x9bP\xd5\x88\x1df\xf8\x01\xc6\x08\x8cT\xd7\xd7pqe\xdc#\xe8\xc2\xf5;\xe1(\xc6\xfe\xd3\xc3`\x95\'\x17[4P\x95\xaf\xbc\x98\xf3K\x8c\x00\xb9l\xf1\x05'
        b'$\xa7sR\x8d\xc8`\xb1}\xa6n\xa9\xe9\xeb\xb1\x8d\x94\xa3\xea`\xf9E\xfb\xce\xbb\x03\xe5\xb1\x83\xc6y\xb3\xdf\xaf\xbap\xa7R\xc9\x8b\x8f\x9e\xf1\x1e\x88H\xa0\x84\xca\xef_\xfco\xd3u\xcf\xf1\xe9\x1d\xad\t\x82\xcc\xb8'
        b"\x7f\xa4W\xb1\xa0\xa4\xa1f\\%A\xef\xa3\x98\xb2\xae'<\xd9\xda\x8d\xbc\x15l#\x88\xb5|\x04^\xaa\x95\np\xc2\xcb&3\x81\xfaq\xf6w\x9a\xe8\x7f\xec\x94\x1f|z<\xfd@;\xa8|\xe4\xd4\xd2\x1b\xbbb\xdc"
        b'\x1a\x13A"\xfa\xb22W\xa3s\x0e\xd9\xda;\n\x1dL\xd0\x01\xc3 \x1cDq\x0c\x01\x1a\xcc\xa4@\x81\xe5d?\x00\x04c\x83]\xbbG\xb4D\x7f\xe63\xf1\x05\xee\x87\x9b\xed\xe1}\x8b!B\x7f\x89h\x9d]}\xa4'
        b'rN+\xb1\xdd\xdf\xb2$\x95%\x02,\xe2\x05\xd1\xab\xb9R\xf8\xb6\xc2\x06\xdbn<\xd8\xd8j\x14\xe1\x18>\xf3\xef-\x07\xf9\xbd\xb1\x8b\x92\xf5V\x8f\xb27\x835\xa8uM\x81{\xe9G\xb5\x9e\xfdw\xf0*H\x87w'
        b'\x89\x8f\x07u\x9b3\x98\xdd\xcd/\x10\xe2RS\xc5%\n\xda)\x7f\xf8\xba\xeb\x01r\x0f\xeb\xb6M\xb7l\xdd\xcem\x7f\xa5Z$\xac*\xdfr(\xd5T2\xf9\xf9d\x96\xf2\x1a\xa4\xf2\xcf\x92\xaf\x8e\xccw\x92\xfa/\xfe'
        b'lK\x81Aw\x88\xf31\n\xd3\xbec\xe4\x1b\x1fw\xcb\xdbW\xf6\x05\xcap\xbd\xef\x8av\xbf\xf7(1\x01\x17=\xb6\x93(T\xa5B\xe3<\xeb\x8f\xb9J\x88<\x12\xb00\x7f<\x8b\xf5\x87\xc8A\xdc\x14\x12\x1bF\x99'
        b'\xcb\x13\xe4wt\xc7\xc9\xd1\xaf\xc2Y\xafbU\x95j{\x1fA\x881/k\x9c\xbb\xc8\xd7;yo\xf5<\xb2s\x9d\xe6\xa9\xca\x94\xa6X\xf5\x99#\x87\xben\x06f!J\x99vE\xe8@\xf1\xa6c1\x94|ai'
        b'\x01\x00S\x12k\x93\xfaT#p\x9bSw]\xbf\xff\xe0\x15\x88\xaa\xa7\xdb^e\x82AAx#6\xd2,\x8e{\xf2=\x07\xcbFA\x1eV\xdc\xa4{[.r_\x07\xc8\x0b\xb2S\x19\n\x94\xc3l\x0c\x0b\xa3Qa'
        b'\x93\xbeg\x8e\xe2\xe7w]\x918\xed\x1b\xf0\xcb\xf5\x0f\xc7\x7f\x81\xf2e<S\xa8\x186\xc2\xd8\x93\xc5\xba\xb9&\xa8\xb8\x1a\x11\xa5\xab\x1d\xc1\xfd\xcf\r\x11\xcf\xf1i.\xe5\xf8\xe6\x86\t\xaa\xafc\n\xa0)\x9e*\x81\x88'
        b' !\xe1\xd9\x12\xaad\x80\x80\xda\x14\xcd\xbb\x919\xd4\xa18\xca\x90\x06`\xceB\x83c\xe6VF*t\xfc\x07\xa6?\x17\xa1M\x0f\xecA\xc1\x00N\xe9;-{#\xb7\x95\xf4"kf\x80}gU\xed\x94\xaa\xde1'
        b'\xda7u\x12\xf7\x1a\x18Ft\x14\xbdzSM\x00\xb4C\x87P\xae\xe1a\x94\x11\x8f\xfb\x84\xad\xf1!\xe0\xcd\x1b\xab\xac~\x89\xc9\xcad$wb?\xec\xb5r\x02\xa6\x8aa\x15H\x99\xd93\xd9?\x99#\xcdV;\xe2'
        b'\x06\xe9\x8c\xbe\xfd\x80\x94\x01\x02n\xed\xd6\xb7# \x80\x98\xef\xe2\x90&~\xd8U\x93:c\xc1\x80\x8e\x9b1h\x11\xdf\xba\xe8*\xb4)\x9e\xc0o\x97\xd1\x8b\xd8\xec\xb4\x8c\xe7\x83\xd8\xb0\xc7\x15\x96C\xb6\xc5\xef\x13\xb3\xa3'
        b'A\xef\x1e\r3\xa2\x0e\xb2\x88\x9d\xdaP\x8cA!\x0fUt\xbd\x8a\xef7\x86\xef@[X\xb0\x882?\xe6\x89=\x1c\xa8\xb9Pu\xaf\xe3\xc7\xdcx\xd6yOK\xef{\r\x15\xc4"S\xf7,!\x9a\xd7\x9eU\xa8\xd0'
        b'\xd7\x07~\xdc\xe9\xb0*\xd7\xe3\xfa>j_\\<I\x0f\xce4\x98\x95\xdd\xdb\xdff}5\xca\x887\x0eX\xd5\xf3\xcfX\x99\xbe\xa2\x11\x99\xba]\xb4h\xf8h\x86\x11\xe2\xc1\xce&\xf9=\xe3\xcc#BL\xf8\x0c-f'
        b'\xf5b\x0f\xe1\xb2\x10R\xa8\xaf\x8b\x9a\x07\xf3\x9dNu\xb1r\xb7\xad2yj%8\xccf\xb4\n\xaf\xb5e\x94\x96:\x03KI\x1e\xcf7\xe5H\x12\xedu;\x00\xfd\x07\xed\x88;\xc5\xe5\xf2s\x9a2\x96S\xd8\xc7K'
        b'\xbb\xe2\xe2\x8fB\xb0\xdcT\x1e\xbf\x19m\xb5\xffxP\xb3\x88\xeal5\xa9&\x16\xdaE\xc7\x1e\xae \x17\xa6\xf8x\x1ad\xb4]\xc6]=\x1f\x1b\x1e\'\xb0\xb6M]\xeb\xc0M\xab\x0e"\xb7Y\x82^#\xdaB\xea\xe8'
        b'\x1f\xa8\x08\xb9\x1c+\xe7p\xeb=\x88\xa6\xa3q\xf0\x9b\xd4~()sf0\xfb\x03\x9cG\xb1d\xb3\xa7\xa4\xb0\xfb\x18\x85\xfb\x086\xfb(U\xb8\xb0> J7\xc0\x9d-\x0feM9\xab\xf1}\x1a\xec\x10\x93\xe61'
        b'l)\x1a\x1b<\xa0[\xe7V\xf0\x93GE\x8d\xaaW\xe6\xe7\xb6q\x8a\x15\xef\xd7\x16\x8aH\xa4Lc\xdf~\x84#!k\x07b82\r=FkB~#\\Tr\xfb\x0f\r\xa7\xba\x9c\xf4\xa1,NrtP\x15'
        b"\xd66wA\xe7C\x99|\x80\xe0\t\xf4x\xbe\x9a\x02\xb6b\x85\xc4\x9fC#\x90'\x19\xf5\xf2~R\x1d\xf9\x96\xbe\x02g\xd2\xc1qV\xaef\x8f\x8fKi\xa6\xe0\xe3\xb8\x80:\x05\xfaQ\x8b1\x19\x91\xe3\xf6G\x10-"
        b'\xf1;\xb6#\x08=\x1bk5\xfe\x0c\xd0\xa0\x8b\x80\x1f2\xc3\x10\xbb\xd9\x90\x10p\x1a\x12\xba6\x04NC\x86\xcc\xbc\x1e\x00\xe9\x82\xb7g!\xaa\x03\\\xbf]j\xdcwi\xeeL\xab$\x9e\xca\xdf\xae\x88n\xae\xcbVQ'
        b'\x05:\x1cZ\xd8\xfb\x80[\xbfx\xd2\x7fb\x84`\xdb\x99\xc8\xad\xeb\x1c\x0b\x15\xbfO\x1a\xcc_\x13]5\x9ef\x8a\xc6\x81@"XsPrx\x11:\xe7b\xdb\x88\xc1"m\xacc\xaa\t\'8_\xf1\xb7T\xcf\xc0'
        b'\\\x9a\xf6G\xa0S\xeacI\xfcA\xcf\xdf\x90!\xe8\x96\x19\x93\x9e\x8e\x8b\x10D?6\x10\xcbI\xc1\xef\x81o\xd1\x8f\xfa\x19\xbc\xf5\t\xe2\xa5\xbb\xda{R\xa3\xb1\xbd@\x80#8\xd3\t\x1bxzsW\x87\xd0\xa5\x9b'
        b'k[ME\xe4N\xabA\r|a;\xe6\xc2\xff5\xbf\xc5\xa1\xc7u\xce<%\x9f\xb1C\x8cA\x7f8\xc3\xfa\xf5! \xc4\x01\x16[\xb7\xca\x93\xec\xf4\xc3\x01=\xa0pK\xd2\x9a[^\xd2\xc4\xfc\xdcC\x8a\xfe\xd3\xbb'
        b'\x02S\x05\xe6U\xcbW\x06\xfa\xf3\x0c\x85\x91\xb1%;-\xca\xaf\xa7\xec\x84\xe8\xf1\x11\xbe\xb5\xce{\x9a|\xac\xf1\xaa\x8at\xf2\xa1\xcfY\x87\x04\xa4**!L\x8f\xb4\xb7\x14\x06\xf2\xc4I\xeb\xeaF>`\x96\xfe\xaf\xf7'
        b'\x922\x0e\x18^\xa3\xac2Yc\xcf\x94%\x8d\xa7\x14,h\xb8N\xee/W\x9b,\xd01\xaa\x0c<\xde\x8c\xb5\xf7\xa7\x8cR\xdd\xfe\x8c\xb7P\xb1ClDrVb1\x030\xfbbNj8eLwRG\x16\xd8'
        b'\xad\x12\x7f\xcaBG\x9b\x0f\x9e\xa1BF\xee\x976\xcd_\x18a%\n"\xb3Ls\xd3\x9bfg(\xcaJ\x0b\xb9\xde\xe7B\x9c\xb1\xdc\xca1\x84=\x86\xae\xadH\xa2K\x01\x9e\xdfus\xc8\x18"S\x98\xb8eP\x13'
        b'\xdd\x7fz\xf6\x95\x9e\xaaiA\xc7)O4|\xca\x1e\x9a\xfaxN<cH~\xabg\xf5\xb3\xb0\x97?\xf0\xef\x13l/\xbeSBp&\xb1\x02Wd\xbb\xb02n[y\xc51\n+\xfb\x006l~\xb8\xca\xe4\x01'
        b'-\x04j\x92\x17\x91\x18\x9f\xe6\xd7\x00\xbf\xbc \\\xad\xad\x89oS\xc1\x11\xa8\xa7>\xed\xdf6)>OC\xed\xc5B\x08\x19\x99\x9a\x83\x7f\x19\xdf&\x80\xb6e\x04\x13^\xdak\x16s\xde\x11!?\xba\xc4\xbf\x97=\xf6'
        b'_\xff\x18\nF\nI\x80i\x0e-\xb5}\xd2\xb0M\xfd\xec\x0c3\x15`\x96\x81\xcf\xaaq\x8a\xd7\xfdVsL\xddi`\xc0\xcd2p\x8b\x95\xc8>0C\x9b\x17CnRLD\xb1\xd3\xcd\x8cy\xe9R=>\xdeR'
        b"\xf3\x97\xf3\xd1D\xf7\x8f\xb0\xec 1\xf6\xd4&\xa38\xa2\x82\xcd\xdb\xc4\xe5'}\x81%/|\xad\xa0\xe7\xea\x04\x1cH\x00*\xa4\xf8\x08\x0cv\x0b\xbbZ%>\xee\xb2d\xdd\xee\xf5C|M)\xbb\xee\xe4[\xd6\x0f\x8b"
        b'\x06\x87\xa2\xb5Yi\xcc\x03p1\xe5OY\xb0\xca4\xeb\xbc\xc6R8#\x9ag\xcd\x9aC\x9c;\xcb\x92\xa9\xd3\x96\x9d\xfcy\xcd\xc2y\x8f\xe72\xdb?^\xbbU\x11\xd19\xa3\xc6N\xba4IQe\x9c\x00\xdfM\x92'
        b'\xae\xdb\x12\x94\x06\xae\x00\x04hfuQO\x90\xaa;SH\x94\x17\xff\xaa=\xa3\xbd\xf7\xa7t{f\xed\xd7i\xb2\xe2\x8b\xa0m\x86\xa1p/#\x14Sf{O\xe0]2\xd7Y\x15\xde\x82J\x8323O\xe6\r\x0f'
        b'\x9b\xe2\x87\xd6\x1di\xd7\x18\xc6Y\x1a\xc9@o!\xf5"b\x99\xa7\xc3\t\xaa\xd5vL.\xba\xdc\xda>\x12Tf3\xb9\xe7\x8e\xc3\xe5\x0fp\xf9\xad\x93\x9e\xa4R\xda\x97\x1dM\xd9\x1a\xe0A\xe9\xca\x9b\xa3\xcd\xbd\xb7b'
        b'\xa9\xde\xe9\xce%$\x04\x97\xbdhG\xe6(q]-P\xf7*b\xf6\xf9\xc2\xa1\xd8;K:^\xea\x1dTHe\x8c\xbc:L\xbd\x02\xb9\\j\xfdqE\xc1s\xd2;\xff\x95\x95D\xad\xc9\x97\x7f\xfb\x92\xb0\x01\xcc\xe0'
        b'\xf0K\xb0\x92\xfe6\xcf\x98V1\xcbSK\xdb\x8b]\x8a\xdftUz\xa1\xae\xd0\xdb\xae\xf48/\xe16\x8fZB` \tk#\t;\xe5\xd0\xed\xfe\xa2\xae\xc07:\xaf}\x99\xad-i\x18\xe0\xfa,d\x9a\x83S'
        b'\xe61\xcb\xedJ\x8a\x82\x13\xa7\xc3\xf3\x0b\xc3R\xd7\xf4\x1eD\xa6\x08\x01\x05\x15?0Lw\xc7\xd1\x8eM\x9e\x0f/\x11\xbb\x18\x18\xaf\xe9>\x95\x1b\xa5|\x86\xe6\xcf>\xe0v\x1d\xecV\xdd\x06R\x0fi\xcc!m\x11\xff'
        b'w\x9d\xd5Z\x16\xa8\xd7\xb1W?f\xf0\xbc%Q\x89\xbb\xecj\x81hh*\x1d\xceyB\xf7\x10\x07\nn\xf2U\x9f\xfc\x10\x94\xa8\xdf\x9f\x7f\x9d\xd7\xa9\xf0;\xccbKw7]\xd6\xb1zq\xd4Aw\xe2U\x99\xdc'
        b'\x17:C\r\xdc\xb3\x16+\xed\xc7\xe94\x8e8\xc9\x9f.b\xc8\x86X\xd0\x8d3\xde\xf1E\xc4\xe8\x1c\x89\xa6\x1em\xe3\x00\x87\xdfV\xaf\x14\xeck\x00\xb3\x8b\x0f\xcc\xa2\xeb\xa8\xfe\xb8\xda\xc6 \x81\xb6\xf8\x98\xae\xb0\xde\x8f'
        b'W\xb9ZBB\x10s\x0e\x9d\x95\xf4\xe0O50\xac\xc8$\x92\\o\xf4\xf6^\x12O\xe1\xab\x06\xea\x9ds\xb0\xb3\x9aS\xd8\xa1\x16\xbd#d\x10\xca\x1b\xe1l*=\xe8\x87\x97\xd1\xe1\x96Ki8\xccW\x85\x87]\xd6'
        b'U\xdd\x9e\xde\xe0w\xe29(\xd9\x1d\x9dg\x8f\xf4\x8c\xd4\xd8b\xc9\x9eP\xf1P\x08v\xf8Pm\x9bp\xf0`\x7f\x05\xc2\x03\x935\xc1\xcb-8\x9f9\xa1\xfdO\xba\xbc\xbe\xa2\x90\xbd\x13\x1f\x89\x0bn\x99\xcahw\xd0'
        b'\xaa\xcd\xae\x88\xbax4\xd1O\x81\x0c\xfd\xd6\\\xe3\xe7t\xfd\xceMc\x9f\x87\xf3\xd6\xed\r\xf2_\\(\x9c*\x83\x7f\xc51\xfaq\x0c<\xe6-\xbdO\xe4\xd2o\xa9~\xeb4,\x83\xb8\x1fnf\xf5\xe0\xa52\xa6\x0b'
        b"\xbbz\xad\xea~\xf7\xf2H\x85 *k\xcf\xdb\xae\xb7(\x1a\x81'Y\xaa<XY\xcbh\xf5\xc5\xe6\xed;\xb5\xb8\xb7<\xde\xe6\r\x81-\x8c\x1aD\xab9\x8ex\x16\x1c\x9aI\xff\xd8\xb8\x92w\xf6\xa1\x911O\x98%"
        b'\x02\xe0\xce\xbd\x17\x93\xff\x8d\xd3\xcc\xa2\xdd\xa6\xec5\x13Kt\x1b\x9b\xf1X\xe9?aY;\xfc\xef\xb1vCo\xfa\x02\xba\xe5c?\xef\xa7\x04&\xb5\xa3\xe5\xa5\x91\xa6\xeb\xd6\xa7\xae\xe7\xf9\xc3\x08__\xe9\xb1\x06\xd5}'
        b"l\xf9\xb2\xce\x1d\x87o \xed\xccI\x88*T\xb2\x1e;\xfd\xdc\x9e\xff{\x9c\xda\xf0|\x8b,T\x0c\x8dV1`\xb4^\x0b\xa6\xd9\x16\xcb\xc5\xc3+(\x99\x8e-\xc0\xab'\t\xa9\x12\xe2\xaf\xf89L\xe0_\xcf\x06\xb7"
        b'!T\xf8\xdf\xf1O~\xa0MA\xde\xcf[c$I\x8b\x00\xa9~\xdc\xd1\xa1j`E\x14n\x8f\xfepEB\tZ\x0bx\x81\xc1\xc0v\x99T\x8f\xf3~\x12\x08UBQ\xfb<\x874\x80\xa2\x0b\xbdab\x13\xd2\xc3'
        b"\xa8\x9f\xe5\xccf\x80^'\xb7rM\xd7\xbf\x10\xc5\xe3\x9dlE\xd3\xfb\x06\xc2\xdf*\xb9o\xe4\xce\xd9\xebB\xbe\xe7;\x15\x95\x9e\xa9\xba\x87=W_)*\x1a\xde\x9aj\xcf\x8fF\xf4\x91\x8aV\xb7\xf9*(;\x1f\xb6"
        b"\xda\xe4y\x83\x8b\x01\xa2\xb0\xceN\xd1\xc327\xd1\xe1 \xd7;\xe1\xf8\x03K\xebmx\xe0~\xa4_\x9c\xe3\x9f\xb1\xba\xd3l\x15\xd2\xb3[a\xf2[\xc2\xe2F]A\x02\x827\x07%\x0485\r\xd2'\xf0\xa5\x18v"
        b'\xd5S\xb6*\x99,\x03\x04\xca7\xf9\xd5\xa2\x1a\xab\xa5?\x9aN\xd0\xf7\xc9\xa9\x98TP\xf2~\xe1\xaef\xb4\xe9\x12`\xe2\xa7J;\xe2\x86B\x0c\xc2Y\xa6\x04n\xd9\x07S"J\xf1Wo\xd4\xa6 \xc8\x01)\xc7/'
        b'\xd14\x18#H\xd0\x12tv\xcb\xdc\xe6xp4\xaa:\xf4\n\xd36\xc4\xb1\xa00r|0\x95\x1aY[\x8a\xab\xc2S\x8b\xd8\xa9\x90\xe9\x17f\x10\xe8K\xf8=\xb2D\xfa\x1b\r\xd8\xb1bJ\x1c\xffovXZ\xf2'
        b'RD/{P\x1d\x84\xcf\xc0AAEC\x1a\xb0\x17O\xa3`\x8e\xee\r\x81\x05\xfe\xe8Y=\xcd\xb7\x8e6\x98(i+\xf2\xb7De\xd3\x02\x83\x1ab\xe6b\x88\x90\xc5\xf1N\xeb\xbf\xfeNA;\xaa\xaa\xea\xb5}c'
        b'\x1f\x98~\x04\xfeXd\xf5Q\xa0\x05\xb7\x08G\xc3\x92\x9f\x07\xd5J|\x00\xc0\xe0\x0e\x9b\xa6\xb6\xb4`\xebZG\x14\xc7V\xfe\xe7L\x14\xf4\xb9\x88\x17AoF~\x890\xe9<\xa2\x08&\xdalc\xc0I\x14\x9fz\x81'
        b'\x9b\x8c\xabS}\xa80>1\x8d\xb7\xc8\xb3\x03.\xfd\x91[X\x91\xbd$Tz\x9f\xe1t,\xb6\x1bc\xc9.iP\xe4\xe2~G_kx\xf2"\x1e\x08\xd3\x17\xa1\x92L\xe6\xd0\xa3\xb8B \xf6\x0b\x82\xfe\xd1\x9e4'
        b'i\x82\x8b\xf1\x05\x85T\xd1\x96\x85\x82\xf5\x1a\xe4!\xfeTC\x14\x19\xc9\x12\xf5\xa3\xf88\xa9\x81o\xd9K\xec\xf5pc1\xd8\xd7\x95tkq\xdb\xc6\xc2Q\x8da\x8a\xd4DL]d`\x8b/(\xf5\x92\x8c_\xb5\xe3'
        b'KD\x8c\xc4N\x81a\xe2*@\xcf\x9b\x11p\x1e4\xc1<j\xad|X\xd1\xa3]c\x88>\x99\xeaoK\x02h\x05\xf5\xd5\x17Q\xfa\xf6{\x00G3\x19\xad\xe9\x96\xcb\xc45\x14\x12\x0420\xb3z,~\x05m%'
        b'\xd5\xfb#\xceUTD\xf8\xde\xce\xfd\x99U\xc5V8(\xd1M\n\x15\xb9\xfe\x04\xf8\xaf\xc9m\x91\xc0\xb3\xb4\xb3\xd9\xb58&]\xfc\xceM\x80\x87hrzR\xe6\xe3\x9a\x1f\xef\xc5!\x9d\xaa\x84Dz\xeb6\xa1\xc8\xf9'
        b"i\xa5$\xd7\xc2\x88 L \x13\xbf`W\x92B\xd7>\xb6\x92h\x14'1\x9e\xff\x8d\xe6\xfdZ\xa7$\xa2\x13b\x19S\xf6\x17r\xbc\x874\x15\xec\xfa\x08C}3L\x18\xa4\xe1\x11\xdf\xb0)\xd7\xda\xa0\xfa\xa5\xb6\xbc"
        b'8\x12\xf4\xc9\xbf\xa2\x84/\xea\xee\xb1X#\xa8Q[j\xd4\xec\xe7\xb4Y0\x90\xa74y\xe2]\xb9/\x84\xe14VI\xb5<|\xb0s\xf8\x93KJ\x90\xdfI-\xf3\xcf\xa8[^\x1b\x9d\x92N\xa4r\x83\xb1\x93b'
        b'\xcb\xfa\xde\x93U\xd5\xde\x00o\x06\xf0\\/\xf1\xca\xfb\x91\x7fR\xea\xf1(\xc7\xa6&\xe7\x99.\xf4\xd7\xd6\xe5C\x069 \x9e&\xe1\x18\x1c2\x95\xdd_\xb7\x1e\xf4\x8f;\xb1\xfd<\xf9\n\x8d^\xee/`\xf8LA\xb6'
        b"'\xe5iA\x85\x86|\x1bG\xb9\xd6K\x01\x97\xb3\x80\ta\x12\xf1\x06\xa7y1\x8c{]g\n/\x08\xf7\x00p\xaf\xc0\xe2\x96\x08\xac;K@\x8cuW0]\x03\xe4l\xb1\x92\x10\xe0\xbb\xc5\xfe\xb5\xd7\xb7\x1d\xfc\xf5"
        b'8\xfe\x0b\xdc\xf0\xa4\x85\x00Y\xd3\xe8,\xec\x9f\xea\xa7(\xc6\xc6\xafi\x85\x03\x12\xdev\x18\x7f\x08\x9f}x\xb5\xb7\x87r\xb4\xce4\xc6\r$\x16g\x7f&\xfa\xf6 uN\xb7#\xccL\x03,=\x03X\xacW\x81\x95'
        b'\xda\xd3\xbc\x99\xdf\xbf\x83\xe6\x01\x08\x84\x02\x16\x85\x89\xdf\xb0A3d%\x93WS\xb5-i\x01\x96\xe3\x02p\x03Q\xe7[\xe1N;\xb9\x16\xb7\xae\xdd\xf7\xa2r4>\x9e\xcf\x02;e\xff\xc5\x89\x0c}\x82*\x14\x11\xbf'
        b'\x9b\xe4\x92+X\xd6b\x8b*\xd8f\\\xd9\x17|Cr\xfa\xde\x84h9\xf1\x95\n~C\xfa{\xf1\xdf\xce`\x81\xa8_\xc6%b\x17\xd9P\xfe\xf4\xa1F\xaeC\x90Lz\xa9\xc5\xf40\xf2\x1b\x17\xf8n\x04h\x8b.'
        b"a\xe2\xd2\xba\x7f0P1x\x95uN.\xd5\x88G/'M\xbe|\xf5\xe7\xd4\x98\x1c\xd1\x01\xdc8\xec7\xeb\xfeV\x8dDl~\xce\xa0\xe3\x0e\xed\xbb\xc0\\\xde\xb8\x9a\x04\xde\xb3v\x13\x86\xa98\x80\riz_\t"
        b"'\xab\xaa\x80\xdd\xe6\xbc\x7f\x149\xc8\xfewR{\xed\xf9Q@\xd2\xc0\x1d\xbcT3\x00x:\x9e\xe3\xfa\xcb\x18\x0c\x8b\x00\xba\x0fwC\xda\xedC\x1e\x85\xab\xd5\xb5\x01\xa4\xc69\xba4\x93\x9c\xbaS\xf0\xef\xd8n\xf27"
        b'l\xc2P\xcfVQ\x00"\x97\\2\xabm\xc2\x14K\xd3\xac\xb0\xd3\xef*X\xfd\'\x13n\xcae\xfc4\x81\x88=\xf4*N\x9a\xe21(I\xbf\x93\xa5\xee5\x88\x1d\x03jt\x80m2\xa7\xffTG\x1c,{\xa5\x11'
        b'@\xf11\x06\xa3\xe5\xf5\xda\x99iS\xd8P\x11&{Y\xe0\x18)$\xc4\x98T\x1d\xc9\xc0\xc9b\xec\x0b\xc0\xeaq\r\x9a\xd2us\xf7\x92K\\\x1dA\x99K\xb4/\xfd\x82<\xf7\x81/\xaaQM`Y\x1a\xa6uJ'
        b"\xbfff\xae\x8doM\xddR\xe0\xaeF\x9b0\xa8`\xcc\xf2T/\x91c\xcb!\xc9.\x8d\x01z]`\xc6\x12b\x06\x00\xefD%]\xe4\x9d'&\xd4\xc9bjS\x10H\x8a\xcc&'\xfa^\xb4\x93\x02\xdc\x81\x9d\xbb"
        b'\x1e[\xb46\xe0N\xcc{\xf6\xefD\xbf\x84\xd7f\xb3\xf7\x82\xac{3\x98\xae{\xb4\xc0H\xc8\x90\x02\xea\\\xf5y\xa6\xe4\xcdM\xd6\xd0\x83\x8f]<\xfb\x83%\xcb8\x98<\xc5\x95\xc7m\x13\xfcY\xa6\xb2\xcd\xb64\xca'
        b"@P\xd9\xc4\x91Sxm`\xad\xda\xad4\xd3\x19\xbdj\n,\x12\x8a\x83\xe2=EY\xc7\xf6\xf1~?U\xac0q\xc0\xc7/\xe6\xfc2W\x13\xecP\xec\xcd\xeb\xacJe\x89\x00%\xaf'1U\xd0qm=*\xa6"
        b'~|\xec\xaa4\x9d\x15\x95\x87\xe0\x1c"\x97\xd1\'v\xd7\xec\x9e=\xef*\xc1\xf4\x9f\xbf\xe5Ds\x1dx\x13+\xcc\xdc/\xbfm\x9fCS\xfeT\xc3\xb6\xfd\xf6\xacFk\x81\xb3\xb4\xca\x1cM\xae\xb7\xc3\xb6E\x87\xf1\x87'
        b'E\x0e\n\xa9{xr\x82_\xcd\xf2t\xe0\xdc\xfe\x1c&\xbc\x1aFX\x1e\xbf\x16y\x97\x94\xa0Y\x1b\x0fv\x0e\xda0\xab\x96W\x8a->\xc9}H\x9f7PL\xb8\x0c\x8dW\x9b\x1em\xfc\xa3\x9b\xa62\xa1\x84\x9fL'
        b"\xc1\x8c'\x8aM :\x82\r\xf5yt\xfe\x022\xb7[\x0e\x96\xd1E\xfd\xdd\x0bA\xa6\x8e|\x98\xd5\x90\xa6j\x99\xf6\xa6\xb8\x99Inw\x11\x0c\x02\xb28\r\t\xbbMR\x08\x07\x1b\x18\xb0\xd7\xe7\xee\x82vws\xd6"
        b'H\x83\xe2s\x94F\x05}\xed\xfa\x91&\x9d\xe1\t\xb7\x8d\nx\xca\x87\xf38\x17\x93\xb1i\x8f\x9b\xa6g3\xe1B*\x95\xa6?\xe0\x12\xa0g\xa5G\x1bh\xab\x93\x13c\x83n4\xfa\x13k\x1e\xdb4\xd1\x8e\xd5F\x1f'
        b'r\xc2V6,\x04]\xb9\x0eK\x95\xd1\xbf\xb5\x1e;/|\x0f\xbc\x89\x03\xf5ti\xc9\x97\x85\xebMW\x06#9\xccl[\x0bU\xd2\x93\xa1\xf5\x06^\x87p\xc7r\xc1\xc6\xa6>\xea\xbcP\xeak.\xf2\xf9\x90s}'
        b'\xdd[z\x0e(\x88\xfa\xc5\xf4\x05\xb9\x05\xee\x9d6J\xf5\x96\xa0B\x19\xe6\x91\x07\xde_m\xee\xec\xb3\x88M^\xd9\x8c6}u\x9e\xf6\x0e\xf6\x1b\xc0\x86\xea\xbf\xaa\xa9IZ1ZNV-@\x8b\x91\x0e?\x0b,\x87'
        b'\xda\xdcs\xaf\x7f-\xc0]\x8cxl\ng\xe5X\xc11N$\xd3\x12\x07\xe5K\x9dQf\xbf\tN\xe9\xbd[:\x91a\xa2\x98\xa7Z\x15\xe3j\xa52\x97\x19\xd4\xabx\xc8\xd1\x14\xd5\\\x0fF\xce=\xd1\xbb\xa2\xb24'
        b'(\xa5\x1ch`\xa0E>\xf07\xba\xa3m\nN\x95\xc7\x07\xde\'\x04G*G_\xe7E\xda\x9f\xb2\x89tw\xbc\xdb?\x0e\xd9G[2"\x88\xc9|\x1e\x13\x10\xf2$\xfa\xbaB\x87\x14\xb4\xccs\x9e\xa7\x9d~\xc8L'
        b'\xb3 0X^\xe2\xb6ar\xa9?\xd7/\x8b\xb0SV\xa1}\xd5\xb6\x86\x88\r\x12\xea\xec\xc0\xfbhy\xc1\x06\x96\x9c\x1d\xc1\xbb\r\xea\xf2\x9c\xd6\n\x8c\xacd\xe9\xde\x90\x1c\xfc\r[\xf7h6\xe5\x16\xf0i\x1a\x87\xba'
        b'\xcaT%*\x16\x15\x90\x95wY1&\x0cV\xaaY\x08\xc5\x08\x10\r\xe9\x95\xcbA\x90\x85\xcb=\x81H]\x1a@\xbb\xb7\xd1\xb4\xcbY\x1f3T\xdc?H\xc2\xbe\xef\xd5\xf3\xcf\x99x\xc3\xbdm\xc3\xec+\xa6\x99\xe6\xe7'
        b'\x84\xa6Z\x8b\xea\xfa!\x937%\xb0\xaa\xef\x9dd\xad\xea\xf0A\xf5\x13]4\xd37H\x12Q\x19u(V!\xd6g3!\xe3\xc7\x9b\xd1\xa0\xfe\x9d\xc7\x0eKt\xd6\x13\x07F^\xb2]\xef|\t\xf9\xfb\xc7\xad\xf7\xd7'
        b'\xb7\x97\xc1\x1b\xb3\xcd\xdb\xd5*\xce\xad\xe8\xba\x98\x12\n\xdb&4\xcd\x17\xa4\xd1\xa7\xabI\x16?\x0f\xfe\xd1\x86\xb7\xd4\x18 \xd7 3\x9d\xafL\xc3V\x88\xda7\xb8s\xb4\xee\xe9u6L\x04\xeb\xea\xe9\x0e\x84GD\xf2'
        b'\x96\xa4\x9e.\x7f\xd0\xd2\x8bB\x14\xc7!O&\x1b\xbb\xe4\xa3\x8f\x7f_\x83!\xf7F\x94*\xda\x91\xd5\xeb\xfb\xb2\x0e\x89\x93\xc1\x7fK\x97=+Uo\xa4J\x1ag\xa2\\\xd1\xccIk\xb0\xc5\xe8l\xeb\x0bF\xc4\x19b'
        b'\xd2(\xa0!\xf4\xa0\xf15\xcb<r\xb2s<\x9f\x87y\xb8\xdci\xfc5\x12V\x8f\xb3\xb9\x1d\xcf{e\x02me8\xc2\xc3\xe6\xd7\xb0\x04Q!\xa7\xfc8\xcc\xf6\xc5\x1a\x16\xcf@\x1f\xf6\xe1\xd3)\xd7\xb4\x03W\xe7\xa5'
        b'2\xa7k+\xfa\xa7\x01\x96M\x16.\xed`\xad|\xb4\x97\xc3^\xe8W(\xd1\xb3\x9c\xbc\x9c\xf1\xd3,.\x9e\xec\xa3\xd8\xd6\xe1T+bhXHK\x8eY\xaa\xf7\xb1w>\xa8\x0e\xf7r\xc2\xafk\xf4\x10\xff\x12\xaa\xf5'
        b'`\x85L\ne\x19\x88\xc2mq:I\x0e\x8f\xb9:z\xbb\x9a\x82\x0f\xe0\x1e\x98o\x8c\x8f\xfb\x983\x04\x1a\x11\r\xe1\x82\xd7[\xc83\xdd/\x10<\xdf\x08\xc4\x07\xad\x92\xc3\x99\xe6\xe8\xc4\x95f\xf8\x00\xfb\x06\xb3\x9a\xf0'
        b"[n\x9f\x8c\x8c\x93\xf8\x1e\xa3\x13\x0e\xf9~\x00\x8eFu5^64\xd0\xb4\xacQ\xf8\\\x7fpf\x91\xa9~b\x13$E\xfd_\rJ\xfb\xd0\x9d\x86E\xa2\x87\xfb\x00\xe8\x85\xb552\xe6\x81\x17W\xdf?' &"
        b'Wkv\x0b\xfd\xb1\xb2_7m\xf5\xe8\x11\xf1.m\xe6A;v;\r\xbezVj\x95\xb8 \x96\\\xfbbZ`\x10(\xf9\x89\x06\xd0\xbfYU\xb2\x927Z\xdb\x89<p\xc7\x9c\xd5Qa\x17\x80\xe7XO\xb2u'
        b'\xc5\xc4\x93#\xb4\x0e}\x9a,\x1alC\xf3\xdd\xdf\xa9~(F\xac\xbb\xf5\x16\x919\xfcE\x960\x8b\xc5\xc2c\xaa\x7f\xd1\x9ews0\x8d\xce\x1c\x86\x91$\xd0\xbc"\xea]s\x1d\x8f\x1c2\x18\x1e6\xa2\x1f%;\xb8'
        b'Ll^\x93>\xc9\xf7g\xd0V`2u\x97\x0eoU\x84\x08\xa2?\x03\xda;\x1c\xb4\x9e_hL7\x80[\xe8HX1\x81\xd5\x9cE\xa8\x86}\r\x92\xc6\xb6r/\x856a\xe3\xac\xc6/\x9d9\xa9\xfa[\xc2\xfe'
        b'\x92\x01\x85\x86>\xee\x86}I\xa08\xdaC\xf6\x01\x8d\xb1j\x82\x05\xb4\xb64\x90\xb7\xcem\r\x89> \xef@\xf7\x84\x84\xbd\xa8\xc8\x89\xadI\x1b\xab\xdb\x94\xaf\x97\x0f\xd9N8\x06\xba\xab\x0b\x84\xd2j\x12\xcbx\xed\xc3'
        b'\\-\x7f\x06\xda\x05\x00\x08\xf6\x0e\xdf\xdc\xbc\xb4d\xd0\xd4f\x17\x8a\xf4\xb7?6y\xd0\x05BV\xacP)\x815icrV\x90\xbd\xcdZ\x8e\xb3\x9cE] \x98\xacB\xd5\xb8c<\xd6\xa5\x9d\x0c\x1e\xa5\xf6\rZ'
        b'1\xd0\xcc\xa0d\xa6\xdbHeo\xfd\xca]\xf6\xee\x110A\xac\x94\xd2\xff\x86"\xf9\x95\xa5\xd5\xa2\xb0F\xc5\xb5\xc8q\xdf\xa7X\xd9&\xdbH\xfd\x92\x96\xd9\xd6\x16\xd6\x9d\xd9\x9b;\x05R/\xd9\xd5M\x15\xd2h\xfeg'
        b'\xbc\xff\x16\xc4i\xed\x8a\xd5\x97y\xf1\xdf\x19\xec\xddo\xa4N\xae\xa8\x02U\x02\xbbm\xf5_U\x92\xc0\xddv*\xb2\xad\xfe\x82z7\xeb\xe8j!Q\x88XZ\xa2\x1b\x994\x00\x13\xd6?\xb0\x0fg\xe5E\x0b\x9fG\x8c'
        b'\x94\x99\xfc\x95e"tI\xcf\xf8\xc8\x15V\xd0I\x8b\xbeY\x8b\xb5\xc8k\xe9U[t!\xffj\xca[{\x845\r\xc2\xd82\xba\x9f\x994\x84v\x14\'\x12\xc1\xafF\xa8!\xd5(k^\xbd\xa9\x0e\x127Q\x14\xde'
        b'\x12\xc9\xc5F\xe0N\xa3\xed1\xd9\x87%\x95\xaf\xc3Gj\xb5\xf4U\xd0\x96\xc4\x93\xc3_\xde\xa9\x98e\x9d\xdb\x8f\x14\xb2\x8d\xe1\x96\xb3\x188\xec\xb4\x1f`B3\x83r\xa7\x7fnq\xbf\xe6\x84\x9aqy`\xc1\xa4\xf6\x95'
        b'#<\x1a$\x17\xe26`Z\xd4\xf61\x9a\x8e%\xe0\xe1~\xd6\xeaI|\xa9|\xc5\xb0\xe95~\xc5;L\xd6\x945\x8c\xe0\xf3\xf3\x9b0K~\x92\xa0&\xfaL\xf9\xec@\xc71\x1c\xcc~\xea\x9a\xd7\xec-\xc9\x96\xf3'
        b'\x15\xe6\xecV\xc2j\xb4:\xf6\x8e!xI\xc0\xe8\x04/]\xff\xda\x1a\xaa\xf8\xba\xbck\xf3\x15(\xf0b\xce}\xf8\xd5\xb2N\x0c\xbeP+\xe1v\x83\xf0Pq\x10\x17\xceM\xcd\xeb#Q\xd6\x0f\x14\x1a>\xf7AY\xc9'
        b"_l|65\xa7\x81\xa9\xc5I_O\xf7?>\x99\x00kpyX\\#\xcb:ZS]H\x1b\x9c\x02\xd1\xbc\x80\x88X\x9e\xd8R/\x10\x97\x9f\x9cw\x93t\x85\xc1\xb2\xe0\xb3\x9c\xdeP0\\\x83J\xca'\xc4\x1d"
        b'\xd4\xde\xee\xf4\x98p-\xe7d\x05\xe3 <\xb1\xa2\xa6\xf0\x85\xb9\xa3\x1a\xfd\xbb\x8eq]\xd93r\x8a-n\x8e\xf2\xed\xad\xe7\xb8\xab\xb7F\xf1\xf8\x0131\xff\x80\xf5r%4sK\xc2\x10\xcf\x9b\xee\x9b\x92\x14#q'
        b'\x9d\xf1\x10\n2\x9b~XX:a?A\xa8\x901\x1c\xf7\xf0\x1f\xef\xe5\x96\xac\x01\xbd\x1d\xdeV-jk\xbb\xb2\x9b\xc3\x99\xe8\xd3\xa2\xceL\x99\xc3\xfb*\xe2\x91e0\xc1\xd7&N\xb2+g\t\xdf\xca*:\xa5\xf0'
        b"\xf0b\x11Y\x8e\xbf\xb9K\x00\xd1C\x9b}\xe9\xb9V\x9f\x88\x8dKIB\xe9\xc5\x12\x10\xf3\x8c\x977\xe42\xa1\xb0z\x8b]\x00\x88\xf9H\n\xa4'\x06p9\x86\xcf\x12G\xd5\xe9\xb4\x9d\xd5\xfd\x17+a\xbd\xb1oB"
        b'\xf4\x13~\xa1\x93.\xf93\xde\xe2\x14\xfe\xba\x9e\x90\x1a-7cMp\x12?\xa4<w\x0f\x9d\xd7#d\xe4\xda\xf2\xe19x\x92\xddC\xd3\x8c\x00\xca\xd3\x920i\t\xadK%\xc3\xbc\xe0\x8a"z\x19\xae\x12\xcc\x84:'
        b'0\xb6\r\xc5a\xb0\xe7W&\x9af\xa28\x81\xbe\x1fl\xe6\x13\xbe\xefaKf\x7f(U\x0b\xcd\xbc\x9f\xfa\xe2\xf4\xac\x12\xf6\xce\xe8b\x82\x05\xf2j|\x99\x98\xe1QU\x17;\xb6\x06]\xc7\x03\xae\xf2T\x8c\xe5F\xa1'
        b'\x8d*jt\xde\xf5,\xa8\xacaJOQp\xbe\xc6\r\xaf\xa1\xe9\xa3\xa6\xb5\xac \x02\x967\xc4<\x01\xaf6\xaa\x16ZqWh\xf7\x0b*\x06K\x04\xd0{{\xa5\xe2]\xae\xf1\xc9\xa2\x0ewb\xacb\x12\xce3;'
        b'&\x15K\x92\xad|h\xf5\xcd\xbb{X\xdb\xd7D\xe1\xe8\x1c"\x82\xb9"L\xf5\xa9T\x80\xa5v\xd3\xfbw\xf2\x89\xee\x07x[\x90\xdd\xf2\x950\x9b;tW\x92\x06C#T\xde\xbb\x08\xc1\xffU\x81\xdb\x9b\xfc\x03\xe8'
        b'blx\xe9\xaf\x14\xc5KcP\x01\x05\xf1\x89 \xd2\x1f\xb3\xf8/\xe9\xce\xd2\x9f\x9an\x03\xd7\xd3\xec\xc79i\x02\x85F\xea\x03\x94\xc4\xf9Z\xeb\x11Z\\l\x9d\xb1Snc)<^=\x8d\xf8\x86\xbe\xc8\xac\xaev'
        b'\x93V\xc1%\xd2\xdb\x9a\xb0\x934\x99\r\xa1L\xb3\x9d\xa3-\xa9\x8cr\x00\x02\x08R\xe9s&\xf7\xe0\x8e\x94\x1a\x07\xed\xa7\x10]RE\x89x\xf7\x90\xe7\xeaZ\xb9\xc2mr\xc3{\x0cn\x96\x14\xedn\x9d\x1b\x7f\xd2|'
        b'_\xd1*\xb1\xb4\xaa\x04\xcf\xf8\xa3\x92t\xfc\xfa\x9c\x9f\x12F\xbb\x0e\x11\xb2\x1c\x19\x9aM\xe9\x88\xb8\x9eI\xc1\xce\x16\xadaO\x12\x1d\xd9u\x15_\xc4\x03,\xdc%\xbf>\xa2[Y\x9a\xe4^\x9e\xed\xa66Z\xf2\xf8\x89'
        b'\xea\xa8R^\xd6\xddA\x0cUS)5~\x03%\xe2\xc3K\xd8\x1c1M\xba\x16;%\xb3\xe9U0\x82\xc9\xf1\x86\xdd\xde\x05\x9d\x0c\xa1A\x94\xbd\xaf\xe8X\xd2\x9f\xf5\x8d\xcf\xdf5N\x1c(h~2\xc5X\xb7%\xca'
        b"\xd5\\\x84NT\xbdz\xa4\x01\x93\x9bU\xef\x90\xbb\x08\x14\xfc\xe7|\x7f\xb5N\tG\xcf\xf9\x9f@\xe1\x14t\xe3\xb8\x06\xb1\x8e\x81oH\x08\xd95\x99\xb0kt'\x11\xc1\x84[\xec&\x8b@Q\xe2m{\x83W\xc9C"
        b'C0\xc9+\x92\xbe\xe8\xf7\x91\x87\x11\xd7\xe4\xdb\xb2\ra\xbf\xb0mR\x82\x9eYh\x8aZ\xea\x13\x1c\xecH.\xd2$\xc2\xb3\xa6/Y\xe5\x0f\x9e\xa88A\x18\xb7U[\xc1\xf5e#\x8a\xfa\x02\xcc\x98-\xd7?\x99\xb7'
        b'Q\xb7e\x89\xb0\xbb\x0b\xd4\xe4\x1aH\x93#{!\x9b\xc6\xb7\x830R\xc5\x934\xd4\x070}\xefo`7kL3\x04\x8c\xf3v\xe8\x19\x7f1\xd5\xd5\xcb\xe4\xdb\xcd\xefb\xda\xff\x93\x14Q\xa8\x97\xd9\xa5,\xd3a\xd0'
        b'\x1f@\xb0\xeb\xe3tCm\xf3\xfe\xdf\xb8\x97[O\xf2Ez\x93\xff<\xb4\x08HF\xf6\xd1,\xa1\xdcBE\xed\x0f\x87>\xd9\xbe\xd7\x95\xd7\x0b\x9f>\x92\x97\x05\x10\xad\xc1\xa4\xaeX=\x01V\x8c\x861\x826\x81\x97\xcb'
        b'n\xde\xe1\xf0n\xa3Q\x0e=)\xa4\xc9\xc9\xba\x8epO\rkd\xdd\xf9X`,J?\xf1\x0f\xd2\x18\x8d\x02\x7fb\xc5w\x87\xb4\nA\xe2\xce\xf8\xa8K\x02M?\xc7\xf9Zu\xf7\x08\xca\t?\xd3\xfd\x9e\xfa\xe81'
        b'!\x12Sy\x06\xf2X\xc1\xd3\x14\xb2w\x07\xb7e\xc3\xcdg\x8a\x0b\xe7"\x10\xd25\xb9\xf9K\xfb\xf1\xbdG\x1a\x7f\x83\x01e\x88\x07\xb2\xf4\x99\x92\xe0\x90\x90\x1a\xde\xd2\x85YD\xe9Z\t\t\x87\xc7\xc7D\xf1\xectO'
        b'\xe2\x12\x1a\xaa-\x1f\xa3\xd2j\x86^\xcf9\xb1\xa6\xb9M\xc4\xa9b\x8fUA\x15\x9e\xa9\x0b\xca\xd4k9\xca\xbe\x87\x8c\xf9%\x13\xbb\xea\xe0|\tP\xb0\xb3\xa4\xfa\xe7\x82\x19,`\xb2\xc4\xff\xb0P\x1e\x1cG\xfd\x95\x0e'
        b'\x8fu\xea\x95(\xec\xf3\x9bm\xb0*\x9d\xb9!E\tK}\x13\x12\x1e!\xf5\x81.\xf9z\xb5J\x14]\x1d\x85\xfe\x14\xd5H\x18uB\x80\xd4\x8e\x0b\x12\xc0VQ\xd9\xec\xda\xff\x05\xff\x17~\xcamV\x83\x04\rKm'
        b'3\xfd\xaa\x89\xa9\x91\x84@zE;\xba/\xd4\xb5\xecC\xc0\xa8\xdd\xd7P~UXy\x0e\xc0\xa2\xb9Bs*\x00\xa4\xd5\x88x\xd3\xfc\xbe\xca\n\xa6\x1e\x04\x18\xd9+!lY%\xb5\\G\xef\x0ck\x1a=\xc3\xf8\xc8'
        b'v\x9bp\x18k\xe1*x$\x8cet\x97\xc8\xb0\x8dv\x03\\/\xda\x06\x02\x99.\xc5(B\xd9\xee\x9a[\x16\xa7l\xd6Q0\x9f/\x0ee\xef\xccV^\xe2X\xc7f\x98\x95rz\xa9\xc3\x8c\x0el\n\x7f\xea\x1e\x85'
        b'vV>qM\xbb\xb8\x17s#\x82\x05m\x9f\x00\x82\xbe\xeai~\x8f\xbc\xc8\x83\xe0\xd3\x05*\x87\x04\x8e(T\xc7\xfa\xbbU8\x0f\x11+\x17x\x12\\\xa0\xb0\x9a\xf23o\xe3}\xd9\xc0\x93\r\x0c\xe1\x03\xb3\xc4;\xa4'
        b'O\xc7\xe0\x86\x9b\xd1\xd34\\x\xbfh \xd2\xc7^\xf9\xa2g\tn\xd7\xebW\xdc\x9e\xb9\x89\xa6\xf6C\xf3\x07\xf3p\xd7\x08DW)\x01\x0fY\xc4gP~m\xef\x10\xd7&f\xda\xcfeM\xcaF\x1dn\xf6\x11b'
        b'0\xf4~\xab\x1f5\xd1\xed\x9b\xf1\xcc9\xf8\xbbC m\x0eh\xdd`\xa6\xa0\xba$1l%Hq\x04A\xaa/\x99\xf0j\x8d\xb1\xcd\x1e[\x01{/\x9f\xe1\x9ai\xb4\x17\xdbD\xebic>\x83\x0b\x1dy\xdb\xc5\xe3'
        b"\xcc!\xa1\x82\x99\xa4\xd7\x00?\xf1T\xdbA\xda1C\xae\xb4=\xc05\xfba 9\xe2\xe2\xb6\\\xf5\xc9x\xae\xb8\x08\t\xc1AD\x0b\xc6M\xb6\x021\xa1\x9e\xe2\xa8LD'K\x00r\x8dJd\xc5H\xb4\xff\x1d\x9c"
        b'\x8fdD\xf7\xf1P:\xf8\xba\xba\x06/)\xcb\n\xd9\x10\xd4\xf7SL \xeb\x00\xd4\x8f\xab\xfbE?\x15\x17\xb2}<-R\x97o\xa1)\xcf\xc7>l\xc17\xfc\xbb^\xb1\x15\xff\xe3`#\xcc\x05\x9a?]\x80\xfc\xda'
        b'\xc1),.\xbd\xd3\xa6x\xf2-7\x98\x1d\x06`\xe0\xda|\xb5\x96\xd1F+Y\xa7/\x0c\x9f\xf3\x91\x10\xec\n\xb8\xd1\xd0i\xed\t\xb5np\xbf\x99X\\a&(\xce*\x10\x9a\xce\xe7\x8b\xd2Ax]\x1c3Z\xc1'
        b' \xa9m\xa7Nq\xc2\xde(\x17K\xaf\x19_&\x11q\x8dW\x15R\xc3\xbd\xc0~\xcd\xd4-\xfb8\xc9\xcd\xfc\x03\xcbZ\x0b%\x14\x88o\x9a\xe4\xc9\x0ch8\x08\x10s\xb4\xa7\x1b\xa4m\x16;)\x86\xcf\xda\xc7\xcb\xe6'
        b'R+k\xf3+lzX^\x12\xad9\xccT\xcc\xd8\xcf\xfa\x87\x98\x95^\xc9\xc075\xe6q\xd7\xb30\xe2\x9559\xa5?4I\xc63\xc2\xfe\xe6\xf6\xda\xe4t\xde\xca\xe7=\x92}2\x8b\xa4\xa7\xda\x19\xae\xaa\x8e\xb9'
        b'\x1f\x07\xb1\x83P\xc9\x8bTZ\xa8\xcbu|\x7f\xcf\x01\xc3\xb9i\xcd\xa8)\xa9\xca\xaf\xb1\x95\xc9\xd9\xb9\x8f\x86{\xdbkD6\x9cJ,\xce\x06\xf8\x18\x857`\xc2\xd6D\x84\x96Gh\xdb\x86\xaek\xdf\x1exT\xcb\xce'
        b'\xafS^\xff\xccUw\x858O=\x90+~\xb7\xfc5Aopz\xd1/\xf2\x98\n\xa1\xa5\xe7\xcc\xa7\xf8v\x0ev\xbc\xd1\x16\t \xf0\x08\xfe\x88\x0f\n\xf8\x89\x1d8<\xb0Z>\x9d\x17\xff\x92J/S\xce\x0et'
        b'T~\xeb\x95\x9aj\xb5\xa4\xe48\xe6\xb3\xe2\xcb\xd0>\xb5\xcaE\xf5\xbd\xf2.P\xbc\xb6\xae@\x05\xdc\xd1"\xc3\x12\xc2R\x16i\xc8.$\xf95\x1c~s\x81\x1a\x9e\xfa\x95TVCXL\xd3\xae\xf7\xdf\x85\x7f\x89C'
        b"\x19\x13\xf3\x18\x8c1\x8bb'\xc8^\xc9\xce\xb6L\x01I\xd6C\xce\xbaN[\xf9$EW4*\xc1\xef\xfa\xb0\xd0[K\x081\xdb\x1d\xfe\xb8\xf4i\xbd\xe7\x9a\xe4\xfeL\x13\xa1\r\xa0{m\x127\xa2\xf8\x00\x90-\xb4"
        b'T\xfbH\xf2\x8c,\xed\x0cF\xca\xfb\xfe/\x9a\xf2j[?b\xbf{\xe79k\xdc\x98h4\xbb\xf4%\xe6\xc9W\x05\x17\x86\xca\xca\x90t\x9a\x91m\x13\x0b\xb6-\x02\xe5\xecN\x11QMw"\xbb\x04%\x81o"\xe1'
        b'\xeb\xf9\xe7\xb2\xa3\xcbNC\xb4T\x9e\xdd:\x8dS\xda\xab:\x99\xefL\xa3z\x8cu\xa2\xa4\xa2K`\x00}\xf8vq\xa0\xeaR\x06\x05\xbc\xac\xb1I~/\xfaM\x13\xffm\xb2y\xfe\xfc\x96\x95\xc1\xd1b\x7f\xf3\x08\xc3'
        b'MO\xdbi+5\xaba\xa1\x82\x19\x92\x01p\xd5g\xb7\xd2\xa8\x19[k\xfc\xbc\xdd\xc5Z\x9a\xef\n\xfd?\x1a^\xf1\\\x1d\xeb>\x95\xf5\x17\xd4\x1c\xcf\xea\x14\xea\xc0/\xe6\t\xdeQ\xb3\xde`\xb2}\xfe\xde\x88\xf3\x9c'
        b'\x9c\xfc"=\xf6\xad\xafGS\x90\xb9\xfd\xe9\x1b<\xf7\x12\xf7\x193\x9b\x01\xe2\xc3$\x8b!\xba\xec\xbd\xaf\xd7\xc6\x8a\x90\x9e_\xe7yi\xf8\xf8\x00\x82\xd8\x8a\xeb\r\xf7\x9e\x9b\n\xfa\xcd[\x15\x1c\x1e~\xc1\xd1\xfbCf'
        b'\x17\xf9\xdd|\x11\x8fS|\xdc\x7f\x1a1~\xd5\x18\x10\xb6W\xfc*\xa0\xd1\x19\x88|\xc1\xbf\x87\xae;\xd9\x1b\xaeW\xfbiR\xcac\x96\xcc\x15(\x9a\x1c=\x8e\x9a\x0c\x0e\x9e\xfeC\x0frr\xbe\xb5\x190<i\xce['
        b"r9\x15\xc9+'\xf9D\xed\x06\x1e\x1d\xd3f._\xae\x10`\xb0a\xa1\xfc4\x12\x98\xa9\xb3\xbc\x06\xa5\xa1JIo\xb4\x91\x01\xbbA\xb8IM(\x81\xd4p>\xb3`\xc7\x9f\t\x95s\x97\x04\xdcVp\xfb\xba\x00\xbb"
        b'I\x93)\xec2\xc3\xb8\xceg\x980\xec@\xdc\xae2\xb0\xc8}\xa2\xe0\xb6U\xed\xd3\x8dS&\xf3A\xda\rCe\xfeDD}\xf4\x17\x98\xd4\xbf\x05\x19K_]\x98lDr\xe8s\xb2\x01\xdf>\xe8\xb3\xab#\xd6W'
        b'>\x81m\x97\xbf\x9d\x0e6\x16\x06\nO\xeat\xfcd\xeb\xb4\xa3\xb5\x84f\'\x1c\x9a\xa7\xe3A>m$\t\x1ck\xee\x9e(\xf2\x98{n\xcf\xa7`Y\xf2\x9fa"e\xbb\xd6I\x85=\x87\xee\x97\xf4$\xc9\xf1O^'
        b'9"8\xaa\'\x03\r\x08J^L\x14r1\xea\xb6\xf7\n\xa1Uh\xc0\x84\xbcjdy\xb6\xa7\x84\xff\x1c9\xecG\x92\x17^6\x8e>\xc7?\x07\x7ft%\x97`\x84Y\xcba(\xe9\xfd\xf8\x1e\xc7H\xcfL4\x1a'
        b"\n\xe6\x14\x1c\x81\x87g\x07\xbb0\xf7]\xab\x1e\xae\xcf\xbf3\x98\xb4\x8c\xb6\xaf\xef\x15\x19\x1bw`Gs\xe9%\xf10\xab\xb3\xb1\xc2quy\x7f\x86P\xe7\xb6\xfd\xf8\xe6r'Yx\xe7kW\xd6MKPq\xa6{"
        b'f\xbe%^?Ug\xa7\x91\x07*\xed\xfa\x82\xac\xb2/\xebQ|}C++k\xafW3\xbe\xedN\x133\xd5o\xc6~\x8d\xe7\x0c\x1c\xb4.\x90\xb3wG\xdd\x8f%\xce\xb7\xe8\xea\xbd\xe0\x10I\xf2\x9b\xfd\x12W\xeb'
        b'i\x06s0\xaa\x1eN"N\xa3o\xaf\xb2\xf2z\xab\x9a&J\xaa\r\x84g\xae\xb4A\x84\xaeW\xe2)\xebt3\xc6\xcd\xa0\t?\x99V\x1f9\xad\xa5\xdd\x14F\x1c\xd6\r\xc1M\x1fA\x07t\x9e\xa2is\xf0\x0f5'
        b'\x8a&\xa9\xf0\xba\x81\x04M\x8dg\xddGt\x9fG\xce]7\x00\xa9-\xb1E\xd9:\xad\\\xefjVM\x00\x107\x85\x968C\rd\x9d\x10\xe3\xd1\x06\x16I\xa5z\xb4\x18\x97\xa3\x1c[\xc2\xda\x19\xf2\xd6\xee\xdfW\xa1'
        b"\x8b7'C\x05\xcf\x88\xa3\xe4\xcc\xdfO\x85c\xa4jdD\xaf\x91]\xde\xd0\x9f\xba\xd9^\x8c\xe9\xf7\nk+h\x15\x13\xb4\x0c,\xae\xa6\xb1\x1d\x13}y\xf73\x98\xce\xa6%\t\xff`\xac\xaa\x18\x14\x8f\xab\xe8h\xd2"
        b'\x1f^p\x92|\xdcZ\x83\x15\xe6\x7f\xf6I\x1ce\xb6+\x8d\xc1\xbfn*\xef\xbc\x98\x12\xea!\x89\xc8\x80&\xe5\x87KaV&\x03\xc5\xb0\x8e\xe8=\xb1%\x05\x1e0\x80\x85\x10N`\xf8\xe4|\xf5I\x19se\xf0i'
        b'\xaa\x86\x9b\x03\x85g\xe9\x91\xaaN\xb9-\xf7\x01\xbf\x9e\x87V\xb7\x19\xfa8\r\x98\xf6\x8d\xb9\xe2\xdc\x94\xf9Re*\x0ee\xc8\xc1\x18\xcf\xb8\x92\x81\x9b\x136T\xa1a(\x84O\x93\x17\xb7\x93K\xe9vU\x12\xad\x82\xa9'
        b'O\xd2\xc3\xab\x03\xd8\xac\x86\x8a\xc4P\xa0\x89\x99\xec\x9fNX\xfd\xfbP\xe6\xef\xb75)\xd8\xc6\x9d[\xcb\xaaKZ\x7f\xb0\xf0\x86W\x86\xbf\xdd\xe6\x87\xcd\x05\x93\xc3\x9c\xbb&2\x14T\x96kt\x86\xe5anq\xbe\x93'
        b"\xef?\x8aZ'X\xf9\x9b\xd2\x11\x1a@\xed\xaa\x07\xdd[u\xb9\xa6J\x9d-\x881\xc5\xbc\xd66\xec\xc5\xb3?\x92z\xfaw\xe5i\xb7-B\xeb\xec\xea\xcb\xbe\x90\x0b\xc3uv\xac?i\xf5\xc5\xf6?7S\x1d\xf9\x8c"
        b'K\x9b\xc2\xb0J9\xe1\x11\x85\xca9|KJ\x00M\x9cGG&\x1c\x0f\x1bh\x9b\xab\xd7\xf8\xb0r\xf9:\x90\xc0\x9c\xab\x13\x7f\xe2\x1f\xa4h\x15\xe7\xc6C\xb3\x90N\x8f%V\xdd_\xe9\x01\x00\x00\x00N)\x04Z\x0b'
        b'__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<froz'
        b'en fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
